# MIT License
#
# Copyright (c) 2020 Joshua E Gentry

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# =================================================================================================
"""
    sample_tiff()::Vector{UInt8}

Generate a byte array containing a TIFF image with text.

__Details:__

The primary purpose of this method is to make it easier to demonstrate the functionality of the
Tesseract library by providing a byte stream of an image with text that can be processed by
Tesseract.

The text on this image is the first paragraph of the book War of World by H.G. Wells. This book is
in the public domain, so no copyright exists.

__Example:__

```jldoctest
julia> using Tesseract

julia> data = sample_tiff();

julia> pix = pix_read_tiff(data)
Image (500, 600) at 32ppi
```

See also: [`sample_pix`](@ref)
"""
function sample_tiff()::Vector{UInt8}
    return hex2bytes(vcat(
        b"49492a009e780000789cec9d7f9455d579bf07830a64a06aa0861f2ab1904c702089425321a88321",
        b"585235a044a059262664098d80e28fd445b4d1506ab5b6d5a08b2ec7ba4021a243ac3609030a9518",
        b"59284b4862a3503571352c6c0a6350a3c636e57cdf35bbdfb36ecfd99ff7ec779f7dee39f7cefbfc",
        b"c1ba7338b3f7bbdffd9ef79e7b67e63e51a4288aa2288aa2288aa2288aa2288aa2288aa2288aa228",
        b"8aa2288aa2288aa2288aa2288aa2288a526f1e7ffcf1969696aeae2ef3e5bbefbe4b5f6edebcb9dc",
        b"a80a65c68c192dbd7cf6b39f45e73cf5d45374c2bffffbbf33e37ce0031ff8abbffaab0202e4f8e5",
        b"2f7f59bb5f2ef0ebbde8a28be6cf9f1f2e403b2ef90c1bcf6f7ef39b77de79a7f648a8fd72a91f77",
        b"d2713607dffce637870f1f7eecb1c77efad39f7ee9a59732cf2f6ebffa2ca6b74f9830e1c89123f4",
        b"e57befbd475fd29558765c05f2ca2bafecd9b3e79c73cec9eced070f1e64c6a1dafbbbbffbbb0202",
        b"e430bd7dd3a64deedfc2af77faf4e9175c7041b800edb8e433603cfffccfff4cd3bdfaeaabb50743",
        b"ed974bfd38628db309d8b871e351471db56ad5aa1d3b765c7ef9e599b72285ee579fc5f4f6f7bdef",
        b"7ddffdee77e9cbfffaafff6afade6eb8f0c20bfb486f37f0eb2d1af7de1e84ef7ce73b341d1573ed",
        b"c1b0fb15249fd6389b80e5cb977ff4a31f753fbf0efbd507a1de4e8dfd0b5ff8c2c73ffe71ba75ff",
        b"effffeefb8b7d3ab247ace3de184138e3ffe787a405ff243a1f37feff77eef6ffee66f162d5ad4da",
        b"da3a6edcb87ffdd77f35c769ae6f7ce31b1ffce007e9f825975c72e8d02166f0f3cf3fffa69b6ea2",
        b"07afbffefaaf7ef52b7a70c30d37cc993307cdfbe69b6fd242e87ec07cfb3df7dc432f0f6b074c5f",
        b"9bd4792ebae8a2f7bffffd54967ffff77fefd2dbfffaaffffacffeeccf060f1e4cd98bd7f5939ffc",
        b"845eb60f1a348816fef9cf7fde44fbe4934fd2802fbef8a239a7a7a787bedcb56b97340fa6b7df7b",
        b"efbd53a64ca1f3e92ef7e73fffb94b3ed3eba59c98f716ce3efbecdae3d6713ce297e613c583ea07",
        b"41e7b7d4f0ad6f7dcb1c47fb25ca7f4c3a9fd67d27e8c1ac59b38e3bee384ac579e79d17e710c569",
        b"e585175ea8bde9daba756bbf7efdde78e30d267e14cfbffccbbfd050fff44ffff4477ff44714d2b4",
        b"69d3cc7b65284e84f5bafbc52f7ed1f27fc97c43a63efbd50731bd7defdebdf41aea91471ef9ddef",
        b"7e17971095eec8912337f6327cf870eaaefc50e87cdabbdffffddffff33fff73ea0f6d6d6dd48ecc",
        b"f1254b967cf8c31f7ef4d147376fdefcb18f7d8c7f254e7702175f7c71d4fb3ede9ffee99fd2832b",
        b"afbcf2baebae43f37af4f68e8e8ef1e3c76fd9b2853a27952b7dfb7ffee77f322151ed0d1b36eceb",
        b"5ffffaf6eddbdbdbdb3ff5a94f99e37ff9977f49b1d115f4bdef7d2f5e173d6f9e7cf2c9f47c64ce",
        b"e9eeee1e32640855a9340fa6b7534aefbefb6eba7bffc8473e12bf9fc68f935e2ff5e73d7bf650ba",
        b"12bdd43a8e47fcd27ca27850fd207efad39fd2c9c71c73cc9e5efee33ffec31c47fb25ca7f4c3a9f",
        b"d67d27162c5840db44e3d3b5464f76e79c730e1f2762d2a4490b172e348fe986f6b4d34ee3e347f1",
        b"98de4e21d1be504a291ed31e519c08eb75f7de7befd15a2ebbec320ac9ac8b8ef0e3d467bffa20a6",
        b"b7d383f9f3e77fe2139f887b3b25b9b637d2b33c7d49bb80c661cea76b935e1798e374ff467705f4",
        b"806e39a8d95269c561d0930bdd93a3f1376cd8408517f5fe248bae746a3573e7ce5dbd7a359a97c6",
        b"17f5767a76abbd2f5ab66c994b6fa7db21f39822a1e24c9f43d711a5d7dcd250958e1933c61ca78b",
        b"f48b5ffca2471e4c6f5fbc78b1f9f289279ea02f9f7df6d9cc71d07b0814466d2f65c611c5ef914f",
        b"6b3c11a81f1ebacfa7fbc9c441eb7e49f31fc3bf2753bbef5ff9ca57a82dfffad7bfa6c7fff33fff",
        b"13bfce42712256ad5a454b306f5ccc9c39f3faebaf778fbf361ed3dbe9dec0fcd76f7ffb5bf38089",
        b"330ddf1fa854a8eb3aae2baacb7ef541e2de4e2ffaccadbbb9243b3b3be941fcbeca5b6fbd65de0a",
        b"40e330e7d3b579c71d7798e3ebd7afa7e3f40cb273e7ce96143ffbd9cfd0f8f40a91e27cfbedb7e9",
        b"ee71f4e8d1bb77ef9e32650add13a2790f1f3e2ceaed8f3df6189d4fe3d7c619bf8cb542b5473569",
        b"1e7ff7bbdfa5f3cd6542371ef41275d4a8511470fffefde9f82bafbc42c79f7ffe79d387e9f2a41b",
        b"12ca3c1d94e6c1f4767aa6335f9aa730fa32731cc7dece8c238adf239fd67822503ffc2074cb7ad2",
        b"4927250e5af74b9aff98743ed1bed3aae91e989e92a853257e03cd1a27825ed7507fa392a6ac0e1c",
        b"38f0b9e79e8bd8fd42f198de9e7e6b8b89330ddf1fa4bdbd0efbd507897b3b71c925979c7efae92d",
        b"35bd9db6ccfc97798b23b3b75bcfa76bf3dbdffeb6396e7e6842afe5a932e9c10f7ef0833d35c4b7",
        b"1069e84682eaf981071ea0fb76bac1b8e5965ba8685f7df555342f551d3da0a72a73fcaebbeee27b",
        b"bbf9497d7c03f0e0830f66f6a2da9ff598e7c477df7d97fade473ffad1c99327d30b556a836bd6ac",
        b"69a9799b7ac28409575d7515b5627a7a326fa448f3607a3b0d6ebe7ce79d774c6fcf1cc7b1b7f3e3",
        b"b8c7ef914f6b3c11a81f7e906f7deb5b1ffad0871207adfb25cd7f4c229ffcbe47bd89bae28a2ba8",
        b"86bffce52ff37132cc9e3d9b5eae52a38bbf0bc5cfc4637a3b7a1bdc1a671abe3f487b7b1df6ab0f",
        b"52dbdbe9a9bc5fbf7ea6b7d38d313da0bb2ff35f26b73ffef18fd138ccf9d66b938a81ee25fef11f",
        b"ffd13dd433ce3883ae7a7a8a5fb76e1dddb40f193284da0b336f6b6b2bbd8437c7172d5ac4f776ba",
        b"a5a16f7cf4d147cd97549cf425ff16a8b5f69e7efa697af06ffff66fe6b8f919627c8ddf7aebad23",
        b"468c98366ddacd37df6c8e48f3607afb8d37de68be343fe2a43beacc711c7b3b3f8e7bfc1ef9b4c6",
        b"1379f5f63befbcf3b8e38e4b1cb4ee97471d1a12f964f6fd473ffa517c9ab9ffa417954c9c0c94cf",
        b"4183065187bfe69a6bcc11143f130feaed4c9c69f8fe20eded75d8af3e486d6f27e6cc99d3f2ffdf",
        b"263defbcf3e29f95d0153d73e64c7e28743eba36e90e903694eea8a9a8a857989f90325c76d96526",
        b"b6d75e7b8d9e83264e9cc8cf4b6ba1dbcbeeeeeed5ab570f1d3a34eeed7bf7ee35bf9f3c75ea547a",
        b"405f9ae3f48ae094534ea11b4e7aeea0baf2ebedd4d38e3aeaa86bafbd96e2a4557ff0831faceded",
        b"fbf7ef3faa176ad1f138a23c98de7ec2092750905bb66c19376edc59679dc58f83d64bab333fbba4",
        b"274d7a10bf19cec4238a5f9a4f148f476fffe10f7f48a7d1ee7cef7bdfa3266cceb7ee9734ff289f",
        b"68df690adaacf9f3e76fdab489fe8bdaf249279d442f42993819ccbb61f42d3b77ee8c0f5ae367ea",
        b"d0dadbf938ad30fd41dadb0bddaf3e4ba2b7fff4a73fa5b6697a3bbde05ab060c1f1bdd083f8f517",
        b"029d8faecdf7de7b8f6a80aae298638ea1464dfbcb8f4ff71e03060c30afbfa8a75d7ae9a5fcbcd4",
        b"88a64f9f4ef7397419de7ffffd54eae60fdfa8ea6adfac8b7fdfe0d0a143b366cda2f3dbdbdbefbb",
        b"efbedadb1e2ba8f6fee11ffee1e4934fa6a712babfa585275e9b777474249e254579a0a64aaf97b7",
        b"6fdf4e19a007175c7041fc46071a07ad975e08d71ebfedb6db5ce2718f5f9a4f148f476f8f7a3b00",
        b"d5036dc4f5d75f6f6a06ed97b40e513ed1bed353b0791f9bf68b9e88132f7ed371f22c5dba74d4a8",
        b"51e60d31038a1fc583eedbf938d330fd41dadba322f74b5114a5fa2c5ab4e8ca2baf2c3b0a455114",
        b"2500f44a8d5eb36cdcb891eeab33ffaa485114456908a8b10f1f3e7cd8b0619d9d9d65c7a2288aa2",
        b"288aa2288aa2288aa2288aa2288aa2288aa2288aa2288a5239caf21516e7c70c4bd57c8e65793643",
        b"e5411abf74defa78605d08e5e72d140f0fafa13a7936b8d7559eebb7f4fd72a7445f61717ecc8054",
        b"cde758966733541ea4f17bcc5b1f0fac0ba1fcbc85e2ed6aac4e9e23615de5b97e4bdf2f771add57",
        b"58b477b26af929cbb3192a0fd2f8ab967f0ff2fb790bc5bbb7570a515df585de5eb4af10f92ea57e",
        b"4c342f8a1f9dcf8c639d579a1f86f5ebd7b7b7b70f1830a0adad6dcd9a3501e3611c82563f26e3df",
        b"64f6519407e4eb1479423de6457525f2814afdbc28cff18039fdbc4c3c524fab150f0faff4faa5db",
        b"e98e8e8e8103074e9a3489269a3871a25147855a2f5357d6eb4edadfa4fedf2a50b4af10f92ea57e",
        b"4c342f8a1f9d8f8ea379a5f941747676f6efdf7fc58a153b76ecb8fdf6dba948cce722068927b3b7",
        b"a7fd98c8bf8990e601f93aa59e50e9bca8ae443e50a99f97c9b321a79f978947ea69b5e2e1e1955e",
        b"bff464473d996e27e8bf68aeb56bd7329f0beab15e5427e8ba93f637a9ffb72214ea2be47d978e7e",
        b"4c7ede74fce87c661c264ef7fc20e866e0c4134f5cb66c597cc47cee77a878183f2cf2635afd9b3c",
        b"de79a8f575a271c2ce9bae2b910f54eae78d709e0d39fdbc289ec4698e9ed634de1e5e77bf2ddd1e",
        b"efdab5cb3ca6dddcbd7b37138fc77a235b9da0eb2e12f6376fff6fe914ea2be47d978e7e4c7ede74",
        b"fce87c661c264ef7fca024ecdbb78f4ea0524c1c0f150fe387457e4cab7f93479407e4eb44e3849a",
        b"d790ae2b910f54eae78d709e0d39fdbc289ec8cbd39ac6dbc3ebeeb79d3c79f2d2a54b29750f3df4",
        b"10c579e0c001261e8ff546b63a41d75d24ec6fdefedfd229d457c8bb151c1d6afcbce9f8d1f9cc38",
        b"4c9ceef941493035b675ebd6c4f150f1307e58c68f99f66ff2b8e781f7874a3da11ef94fd795c1d1",
        b"072af5f346591ed29c7e5e148f9fa7358db787d7dd81482dddb4caa38f3e3af387987eeb4dd709ba",
        b"ee22617ff3f6ff964ea1bec220bd9d9f371d3f3a9f198789d33d3fd6f0a2ded786c3860da3ab2c3e",
        b"62846501e3417e58a6e7a4fd9b3cee79e0bdb1524fa847fed37525f28146723fafa8b77bf864adf1",
        b"f8795ad3787b78dd7b3b75e9aeae2eca0f9f76eff546b63a41d75d24ec6fdefedfd229d45788f65a",
        b"eac764e6b5c68fce47c7995e2aca0f62f5ead5471d75d4f2e5cba93e69f6f6f6f69e9e9e80f1203f",
        b"2cd373acfe4d06f73cf0de58a92754947f6b5d79f840a57e5e94e7507e5e6b3c7e9ed6341e1e5ee9",
        b"f54b053f6fdebc6ddbb6d1c9fc1b321eeb35df62ad1374dd49fb9b74bfaa4371be42b4d7523f263f",
        b"6f3a7e743e3acebfbe70cf0fc3dab56b4f3bed34eaba63c68c59b56a55d878901f96bf9f4cfb3779",
        b"dcf3c07b63a59e50f779515d497da0523f2fca73283f2f8ac7cfd39ac0c3c32bbd7e172f5e4c9546",
        b"839bf399dff6f75bafc15a57d6eb4edadfa4fba528e5a2fe4da50e6cdebcb9adadcdbc70a07f9f79",
        b"e619ea8d2fbffc72d971294ab3a1fe4da59e747575b5b6b6ae5ebd7ae7ce9d4f3ffdf4b5d75e3b78",
        b"f060fe6fe51445f140fd9b4a3d3972e4c8ca952be9d67de0c081743b3175ead4da1ff52a8aa2288a",
        b"a2288aa2288aa2288aa2288aa2288aa2288aa2288aa2d4998a7809df7df7dd969a0f562d0217df65",
        b"d1e4f133161d7f90f1bd7d9d08a9c7d3bd9ed17af93c54cd2b5a35fa9aefb8b254c74b687afb7df7",
        b"dde737be0b2ebecba2c9e3f02a3afe20e30777ba893c9ea27a46ebe5f35029af68d5e86bbee32a53",
        b"1d2f61a2b7ff772f7e73f1f0becba2c9ef672c3afe9ce397ebebf4f0cfa2f5965b270d4a5ff31dd7",
        b"8746f712d6f6767acd75f6d9679f75d659e6c557285faa2171cd7af846997c5ae7f5f0335af36f8d",
        b"3fc2de4fe4d9e43db939f3837c9d1e79967a3ca5be5d944f741cc583fca11ef529f2f08a3caa4c9c",
        b"c80f8be695f613340eefa54d13d0f3cbf4870ad2e85ec2b8b7bff7de7b54a85478f1851fca976a48",
        b"5fb352df28ca279a57ea6744f947f123ef27f26cf29edc9cf9617c9dd23c4b3d9e52df2e5a2f3a8e",
        b"e241fe50697d4a3dbc228f2a1327f2c3a279a5fd048dc37b69d384f2fcf2fda18234ba97d0f476ba",
        b"35a25b117a328d7739ac2f35b25db31ebed198da7c5ae795e681c9bf357ec6fb69f56c667a3373e6",
        b"07f93aa5e3c4b87b3c23896f97592f7f3c1d8fd51f2aad4f0f0fafc8a38ae28c801fd6d1a79cd94f",
        b"9871782fad95209e5fbe3f549046f7129ade3e62c408faf7d65b6f8d8f87f5a546e07e4ce41b45f9",
        b"b4ce2bcd03937f6bfc8cf7d3ead9ccf466e6cc0ff2754ac78971f7784612df2eb35efe783a1eab3f",
        b"545a9f1e1e5e914715c519013f2c33afa89f30e3f05e5a2b413cbf7c7fa8208dee2534bd9d5e527d",
        b"e94b5f1a3060c04f7ef213733cac2f3502d7acbb6f94c9a7755e691e98fc5be367bc9f71026b3d9b",
        b"99decc9cf941be4ee93831eeaeb748e2dbe5d7cb1c4fc763f5874aebd3c3c31b9fe0e251457146c0",
        b"4582e695f613267ede35632588e797ef0fd5a4a1bd84b5efb7d342dadadaccbd68585f6a04ae5977",
        b"df28934febbcd23c30f9b7c6cf783fad9ecd4c6f66cefc205fa7749c18516f77f7edc6e4efed567f",
        b"a8b43e3d3cbc526f2cf29c5a7b2c9a57da4f98f83d7a7b10cf6f23f6f686f612d6fe9e0cc54cf9a7",
        b"8bc8fc57285f2af25d4612df28934fc61d2cf233a2fca3f8adde4fc6b389f216243f8caf53344e24",
        b"f7784642df2e5a2f3a8ee241fe50697d8a3cbc1ede581427eab1d6793dfa09ca83476f0fe2f96dc4",
        b"deded05ec2c4efb73ffcf0c32dbd3fca67c697fa4991efd2e0ee1b45f944f37af819adf947f123ef",
        b"27f26ca2bc05c90fe3eb148d13c93d9e0677df2e5a2f3a8ee241fe500f7faec8c32bf5c6a238518f",
        b"45f34afb091ac7a3b75bc7977a7e1bb1b72b7950df284fa8fc34599e1bc51fda28712a4a28d437ca",
        b"132a3fcd9ae746f187364a9c8a120af58df284ca4fb3e6b951fca18d12a7a2288aa2288aa2288aa2",
        b"288aa2288aa2288aa2288aa2288aa2287d9c86f6091e3c7870e4c891975f7e795901e4f199f214ed",
        b"912c9afc1ed2a2e1ebbcd13da7a1aeeb46afc304a5fb790dc5f58d9846f7091e3a7488a23dfef8e3",
        b"cb0a20bff3ce4ad11ec9a209e2212d1abece1bda731aeaba6ef43a4c53ae9f37a6a0be514b13f804",
        b"ffe22ffee2339ff94c59b317b447457b248b26a087b4381aabce4584baae1bbd0ed394ebe78d29ba",
        b"b797e213a4eaa231699c9123473ef9e49313264ca007fbf6edf31bfff0e1c31ffef0878da62746ea",
        b"852cd467ca783f193fa6755fa4f18bf2c0ec0bf2ab227f258a1fc56970efed41d61be13a479e53e9",
        b"f8d6bc319e62fe3aa2f270ecb101afeb4ad5a19fef3801f2f31a9141ec23a31a38f6d863f9f8519d",
        b"04f141e7a4149f20ed5d4bef07364e9e3c79c890210f3ffcf0a9a79e7af3cd37fb8dbf77efdef8a3",
        b"2063a45ec8a27da6c8fb89bc90685fa4f18bf2c0ec0bf2ab227f258a1fc56970efed41d61be13a47",
        b"9e53e9f8d6bc319e62a6cee94973c08001e61b3309755d57ad0efd7cc709909f97e9ed287e542741",
        b"7cd0f9a9bf4f90f6ce785aa90cce3df75c7a406b4f9b17f2f80aa55e48d1bc529f6904bc9fbc5fd2",
        b"ba2fd2f8457940fbb207fb55197f6566fc096f66e4fb9e8cf77aa3ac3a4f3b3544e3a3bc319e62a6",
        b"cea9c0e86922b6ca6612e4ba46e3b810bc0ebd7dc709909fd7c81cadbd9d8f3f5127a17cd0f9a9bf",
        b"4f90f6ee8c33cea007575f7d35bd60897a2f6a7a1c6afc48ee852cd4671a01ef27efe5b4ee8b347e",
        b"511ed0be307e55c65f698d9ff1664692de1e64bd11ae7343bab78bc64779633cc501bd9c41ae6b34",
        b"0ea2d03af4f61d27407edec3870f33efc930f127ea24940f3a3ff5f709a2bd0bee2b74f44216ed33",
        b"35a4bd9fbcd7d2ba2fd2f84579e07bbbd5afcab812d2f167c6e9d8db43ad37c28e0643bab78bc647",
        b"79439ee228a80322c8758dc6b152741d7afb8e13203f2f3d0bd3034a8b397ed75d77c5bd9d8f3f51",
        b"27a17cd0f9a9bf4f10ed5d405fa1c80b59b4cfd490f67ef25e4eebbe48e317e501ed0be357657a7b",
        b"3a7ede9b1939f7f650eb8de4bd5d343e9337aba7380adadb835cd7681c2b45d7a1b7ef3801e3e76d",
        b"6d6da5b0cdf1458b16c5bd9d8f3f5127a17cd0f9a9bf4f10ed5da8f1a55ec83af84c23e0fd445ec8",
        b"08ec8b287e691e98f7caac7ed588edede9f8993c33ded5e2d61be1de6ef59c7a8c8ff266f514476c",
        b"9d530cb4d22f7de94bcc74b504b9aed13856ea5087529fac15c6cf3b67ce9cd1a347777777af5ebd",
        b"7ae8d0a1a6b733f1231f6e101f7410eaec1364f62e94af50ea85ac83cf34b2793f9117d260f5d28a",
        b"e217e581d917e457e5fd95e9f8519cbc77b5a0f546b8ce91e7543a3eca1bf21433757ef0e041fadf",
        b"c18307f333d692ffba46e3208aae430f9f6c1ac6cfbb7ffffee9d3a7d3754dd1de7ffffdf45465fe",
        b"2017c58fea24880f5a69209accfba9d499e5cb97d3eb9ab2a35014e57f6956efa7524f0e1f3e3c66",
        b"cc187aa15476208aa2fc2fcdeafd54ea09bd78bfebaebbca8e425114455114455114455114455114",
        b"455114455114455114455114a52a349c37b03a5ed7b2fc9e5682efa3d48f196a5faae627ad5a3c8d",
        b"4e75aedfa6a7b1bc8195f2ba96e5f7b412761fa57ecc80fb52353f69d5e269682a75fd363d8de50d",
        b"aca0d7b5fe7e4f2b61f751eac7ace0be281544eba49e34903750ea7fb4cecb7818d1ba50fc86446f",
        b"371f161a7f6f4f4f0f7db96bd72e669c205e57b48f11f07532fb2bf56306d99708d70ff2b15a61f2",
        b"8f3c9e687c148f349fd2fd8d7a950dededed03060c686b6b5bb3660d336fc47a42ade3a0fc33de5b",
        b"ebf8d27505a913c63b6c85f1d24af3c0f7810ad240de40a9ffd13a2fe36144eb42f11b12bd9d5277",
        b"f2c92753fd982fbbbbbb6916f37974689c205e57b48f11f07532fb2bf56306d99708d70ff2b15a61",
        b"f28f3c9e687c148f349fd2fdedecececdfbfff8a152b76ecd871fbedb7537b319f13887cb5c8138a",
        b"c641f9477940e34bd715aa4e9077d80ae3a595e681ef0315a4b1bc81eefe47342fe369b5ae8bf799",
        b"46b6f764a84ac78c19631e53115242f87182785dd13e225f27b3bf28cf0cf9f725feaeb40b83f1b1",
        b"5ab1e63f41adc7931f3f118f473e45fb4b4f43279e78225d0ef111f339f68cafd6ea0945e330f947",
        b"79401e528fba0d522756ef30027969a579c8acdb0ad258de4077ff239a97f95c68ebba789f6964eb",
        b"edcf3fffbce9abc6c44165c08f13c4eb8af611f93a99fd457966c8bf2ff177a1de6ef5b15ab1e63f",
        b"c21e4f7efc443c1ef914edefbe7dfb689cf4273d32be5aab27148dc3e41fe5017948a5751b05aa13",
        b"ab771881bcb4d23c64d66d05692c6fa0bbff11cdcbf476ebba789f69047e963a61c284abaeba8ad2",
        b"48e564de18c91c27a7d715ed23f275f2fbebeec764ce17ed4bfc5da8b723f7879574fe198f273fbe",
        b"b5b74bf31939efafe9c95bb76e4d1c677cb55627051a87c93fca03efbc70f7d246e1ea24ed1d4620",
        b"2fad340f99755b411acb1be8ee7f44f332bdddba2ede671a81de7eebadb78e183162dab469e69d7c",
        b"260f685e341df251a27d647c9d687f23891f93395fb42f31417a7b3aff8cc753d4db3df229da5f6a",
        b"9bf45a83ba657cc488db9879adbd178dc3e45fdadba55eda285c9da4bdc30c562fad340f99755b41",
        b"1acb1be8ee7f44f3a2deceac0bc5cff83df7efdf7f542f94def8a0759c505e57661f91afd3babf4c",
        b"9e0bdd9708d78f476f4fe79ff181a2f1513ca27c7af855e9db29d4e5cb97d3f31165a9bdbdbda7a7",
        b"879917f55e340ecabfa8b77bac2b0a542711f00e239097569a07269e6ad270de4077ffa3755ee6be",
        b"1dad0bc5cffb3d3b3a3ae2ab8f1f2788d795d947e4eb44fb8bf25ce8be44b87e3c7a7b64cb3ff278",
        b"a2f1513cd27c4af79758bb762d9513853a66cc9855ab56f1f332ef9958c741f997deb77bac2b0a51",
        b"2786b4771881bcb4d23cf0f1288aa228f951efb0a2284ad3a0de61455194e643bdc38aa2288aa228",
        b"8aa2288aa2288aa2288aa2288aa2288aa2288aa2f42990f753eac10cebcd74f7c39635bed4978ae6",
        b"2dda9f5b1c55f378d6c7cfebb7efcd44a53cc80a82f17e4a3d9861bd998e0ec1b2c697fa5299790b",
        b"f5e7164ad55c6f75f0f37aef7b3351290fb282907a3feb46c57bbb77de42ad4b7b3ba2503f6f65af",
        b"97fa53110f721e4af40932be45abe7d13aaf87f71379309117129d2ff5ab4afdb0c8ef89e2948e8f",
        b"e2b7e68dc9339ab7687fae95d81b7be699679acfb08a3f804e5acfc8e3c9fb6ad3f306f1e1c6247a",
        b"0ee3ff457e55d1be7bc4e9e151b5d6b3d46f8b8e5bf3c0f43d6b9ea59ed680f9f1a6449f20f22d22",
        b"cfa3755e0fef27f260222f243a5fea5795fa6191df13c5291d1fc56fcd1b9367346fd1fe5c2ba6c7",
        b"8e1a35ea8e3bee78e289273ef9c94f8e1d3bd6dc884aeb19793c195fad75de203edc98746f6f01fe",
        b"5fe45715edbb479cd2f5a27a96fa6dd1716b1e98be67cd7324f4b406cc8f3725fa04adbe45e47964",
        b"e6453d2762bd9f690704f242a2f3457e553f3f6c4caddfd31aa7c7f88cef329d3794e7cc790bf5e7",
        b"a6497863a95fd197dddddd1e9e50abc73301f2d5c6f346817cb8f191746fb7fa7f19bfaa68df3de2",
        b"94ae97bfeed2e3a3fdb21e4779407d2f9e31dddb459ed680f9f1a6449fa0d5b7883c8f685e6fefa7",
        b"b5b75bbd90e87c915fd5c30f8bfc9ed6383dc6677c97e9bca13c67ce5ba83f378de9b1ebd6ad335f",
        b"d2357bf4d147df79e79d1e9e50abc733627db5e979f93c5b41fb6e48f776ab8f80f1ab8af6dd234e",
        b"e97ad17527f5db5a8fa33ca0be177f63bab78b3cad01f3e34de93ec1846f11791ed1bcdede4f6b6f",
        b"67bc90e9f3adf187f2c3327e4f6b9c7efed974fc8674de509e33e72dd49f9b26e18d25a8c7d21d97",
        b"8727d4ea8c70f4d5c6f3d62e3c8f0f373e41d4dbad7e55261e774f6e669cee1e556b3d7bf86dadc7",
        b"511e50df8bbfd1fab354774f6bc0fce4a12c9fa0d5b7883c8f68dec8d7fb99bfb78bfcaa523f2ce3",
        b"f7b4c6e9e19f657c97d6bc59f39c396fa1fedc34a6c7de70c30de64bf3929c2ac7c3136aededbcaf",
        b"363d6f14c8871b9fe0d8db19bfaa74dfa5714a3daad67af6f0db5a8f3379b0f6bdf81badbdddddd3",
        b"1a303f7928c527c8f81691e711cd2bf57e220f26eaedd6f33dfcaa223f2ce3f744718ac6e77d97d6",
        b"bca13ca37903fa730f1e3c3872e4c8050b16a0e5c4981e4b29bafffefbbffffdefd3d4e3c78f37af",
        b"f1a5f56cededbcaf363d6f281f6e04fcbc8c23d2ea57f5d877519c1e1e5574af22f5dba2e3c8338b",
        b"fa1ee34176f7b406cc4f1ecaf20932be45abe711cd2bf57e220f26ea99e87ca95f55ea87457e4f14",
        b"a7747cde7799ce1bca339a37a03f977a3bad7af0e0c1cc720ca6c7d24becd34f3f9daafadc73cf8d",
        b"5f684beb19793c91af16cd1bc4871b013f2fd3db915f55baefd238a5eb45f52cf5dba2e3280fa8ef",
        b"f11e64774f6ba8fc284a7343afe3e2df4264303d36fe996fdd286b5ea5cea8a7555102f2e69b6f8e",
        b"1d3bd6fa13f604dadb9522504faba21401bdd08e7f4d8e477bbb5204ea6955144551144551144551",
        b"14455114455114455114455114455114a552208f67da1759ae3733aca7b57171cf03bf5f55f38156",
        b"d3e79ba6e8eba2ac7d0995b7aad5555fc6eaf1b4fa22cb75ab85f5b4362eee7960f6ab6a3ed0cafa",
        b"7c13147d5d94b82f41f256b5ba52d2587d91d5f4662a0866bfaae603ad5a3c88a2af8b46c903a2b2",
        b"f187f2faf19ec7048ce751ea09b5c2f810195f6aed6704c5be48e4cd2c3a0f28ce48e2938de4de4c",
        b"34be751c0f3f69a83cd06d524747074d3a69d2240a60e2c489468583f64bea03ed6b3e5f84f4ba08",
        b"353eaa67697f407990fa7cd1f8d2baaa27a1bc7ebce73101e379947a42ad303e44e4f144be48e4cd",
        b"2c3a0f284e914f36927b33d1f8d6713cfca4a1f240173b5de34f3df514ed9af95e1327da2fa90fb4",
        b"aff97c11d2eb22d4f8a89ea5fd01e541eaf345e34bebaa2c4279fdd29ec704c8f3c88ce3e2558cc9",
        b"f4215a3d4a565fa48b3713913f0f8938a53e59a937138d8fc6f1f09306c90341b78bbb76ed328f69",
        b"d776efde6d1e33fb25f281f6299f2f9f0af7eb22e0f8c88b9a3827b33ff07dccd1e7cb8c8fe2af02",
        b"a1bc7ebce73101f3b9d3224f281a3fd38768eded565f24f266169d076b9c529facd49b89c647e378",
        b"f84983e481a03bfca54b9752480f3df410e5f9c08103e638b35f221f689ff2f9f2a970bf2e028e8f",
        b"bca8d2fec0f731479f2f333e8abf744279fd32c74980ae65a927148d9fe943b4f676ab2f12391a0a",
        b"cd038a53ea93957a33d1f8681c0f3f69903c10d4d2cda54733d6fe508fd92f771fa8343f5183fb7c",
        b"f924b85f1701c7b7e6d3bb3fa03ee6e8f3e5c7f7a8ab3a10caeb97e9794c80ae65a92794591aef43",
        b"b45e0b565fa4a8b787ca038a53ea93957a33d1f8681c0f3f69903c44bdefb6757575d17a1365c9ec",
        b"97bb0f34ea633e5f1ef7eb22e0f8d67c7af407be8f39fa7c99f151fca513caebc7f80dada06bd9c3",
        b"138a403e44e4f18c802f52d4db43e5818953ea93957a33d1f8d6713cfca4a1f24081cd9b376fdbb6",
        b"6d74307e4386df2f771f681ff4f93288ae8b50e35bf329ed0f4c1ea43e5fa6ffb8d7559d09e5f543",
        b"e35861ae65a92714817c88c8e36948fb2245bd3d601e9838453e590f6fa6757ceb381e7ed2507958",
        b"bc78f1a851a32878733cb6d2f3fbe5ee03ed6b3e5f1ef7eb22d4f8289fd2fe80f220f5f9f2fdc7bd",
        b"ae14a52128cb37b479f3e6b6b636730346ff3ef3cc3314c6cb2fbf5ce7301445519a92b27a7b5757",
        b"576b6bebead5ab77eedcf9f4d34fd38bf4c18307bff1c61b750e435114a52929abb71f397264e5ca",
        b"9574eb4e2fb4e9e5f6d4a9536b7f64a6288aa2288aa2288aa2288aa2288aa2288aa2288aa2288aa2",
        b"288aa2f429d4571896eac7e3e7bbacdabaeac3534f3dd5d2d262dc10a198316346e22f6a6bc9ef51",
        b"e5c79752aeb7b788fcfbf1cd6f7e73f8f0e1c71e7beca73ffde9f4dfcc5610f51586a521e2f170a2",
        b"556d5d75c3f49683070f061cf395575ed9b367cf39e79c93eebd413caaccf81e94ebed2d22ff1e6c",
        b"dcb8f1a8a38e5ab56ad58e1d3b2ebffcf2aeaeae72e371a1b2be3f47aa167f43c4e3d1dbabb6aeba",
        b"515c6fb9f0c20bd3bd37609eade3371c15e9edcb972fffe8473f5a6e0c22faa0af50e41b45f13079",
        b"48c7c3b8d5a4f34a3db652dfa5685d0cd638198f2d9ad79a1fc6af8a90d62d75928b2eba8866a4cb",
        b"d97c962cd35b503cccbe1bd2bd57e451657cb5d6f15f78e18596de0f47355f6eddbab55fbf7efc67",
        b"3548fdad08914738c2f917798133f393c63ace2f7ef18b96ff4b43bc21d3d77c8552df288a07e5c1",
        b"1a4f666f779f57eab195fa2e45eb62b0c6c9786cd1bcd6fc307e5584b46e3b3a3ac68f1fbf65cb16",
        b"9a972e739aaef6e3a013a0783c7abbc8a3caf86ad1f893264d5ab870611cf669a79dc6240dcdcbe4",
        b"0d21f2084738ff222f70667ed258c779efbdf72809975d76195d92665fe8081f7f45e83bbe420fdf",
        b"a58bff31e1454dc7c37833a5f37a786cbd3db099eb62b0c699e9b14dcf6bcd8fa36f179159b75415",
        b"b5f7b7543099bddd1a0fef4b8dc07b26ee1e55e4ab65c65fb56a156dbde96f3367cebcfefaebd1a2",
        b"987923a1bf3841a64798c9bfc80b9c999f048c5f98a01b217a56725f6615e83bbe42a9ef928987f1",
        b"a2a6e361bc99d279a51e5b6b3c11f68a8ad6c5608d93f1d8a279adf9c9f434a511d5ed638f3d460f",
        b"28cedae3ccdb08281ede971a81deeeee5145be5a667cba0fa7e7710a89563770e0c0e79e7b0e2d8a",
        b"993712fa8b23a14798c9bfc80b9c999f048c5f386accdede777c8552df258a87f7a2a6e361bc99a2",
        b"7933f369c5dd77295d5726893891c79699d79a1f696f97d6adf94d95f805da830f3ee8d7db795f6a",
        b"047abbbb4715f96af9f167cf9e4d2f97e809dd7d37a58ebf04528f30937f911738333f0978bf7023",
        b"f6f6bee32b94fa2e513cbc17d51a0ff2668ae68d841e5b261e6b6ff7581702c569f5d832f306e9ed",
        b"d2baa55b4a7af0e8a38f9ae37451d397cc8f189878185f6a047aafbb4715f96af9f1695d83060da2",
        b"0eeffe2e56cede2ef50833f917798133f39380f10b478dd9dbfb94af50eabbb4c6c37b51adf1206f",
        b"a6685ea9c79689c7dadb3dd6658589d3eab165e60dd2db3d3cbcf4cae294534ea11b487a0ea25c79",
        b"f776b4ef7bf7ee35bf7f3e75ea547a10ffdc07e5d97abd30be5a667cba8ba63b1cfac69d3b77a215",
        b"c548fdadd2fc2350fe455e60263f08eb388646eced511ff3158a7c97281ede8b9a8e077933a5f34a",
        b"3db6281ee4bb94ae0b81e2441e5b346f90dece8c8feaead0a143b366cda2fda267fffbeebbaff6b6",
        b"330d130fda77ea12b5f59ff87d15478f2ae3abe5c75fba74e9a851a3e81513933183d4df2acd3f02",
        b"e55fe40566f283407ee1a8617bbba2280d87b7f76ad1a245575e79651121558ab2bc608aa2287990",
        b"f6aeeddbb7d33df6c68d1be9f554e65fbd3501dadb15456944a4bd8b1afbf0e1c3870d1bd6d9d959",
        b"686015417bbba2288aa2288aa2288aa2288aa2288aa2288aa2288aa2288aa2f4718af603d6d9bff9",
        b"277ff227dff8c637a2de3fbb361f35b061c38633cf3c333e01792143f946a5de49947fe938eeebaa",
        b"1a61bd9f0a8fb41ecaad1f778f6ac3794e8ba6683f60fdfd9b575e79a5f96096279e7862d1a245f4",
        b"e06ffff66fe38fa18e801732946f148d8f60f22ff557baafab6a84f57e2a0cd27a28bd7e1c5d7b8d",
        b"e8392d9aa2fd80f5f76f7efbdbdf9e3c7972d4fb3c3e61c284a8f763ff6fbcf146febb42f946a534",
        b"5ffebd690eef67c591d643e9f5e3d8db1bce731a8a207e400f0f26f242224f28f2248af8c10f7e40",
        b"2fcda2defb587a2a3f7cf8304d6194a98c17d21a27f28d2244de4926ff527fa5745d28ff0c56ffac",
        b"b5ae905754eafd8c58ffa6351ea987d73a8ed437ca785d3de249c35c77457b87d1f9d67d6728d463",
        b"cb5c4722ef2a83f57cdaeb969a0f43ebe9e9a12f77edda1515dcdf1204f1037a7830911712794291",
        b"275104750cba18df7aeb2d5af2f8f1e3376ddaf4a94f7dca5caac80b29f58d2244de4926ff527fa5",
        b"745d28ff08e49fb5d615f28a7a783f515da178a41e5e348ec837ca785da5f15861aebba2bdc3e87c",
        b"ebbe3314eab165ae23917795c17afe9123474e3ef9e4f873e3bbbbbb69f7cde76416dadf6a09e507",
        b"f4f06046c02b8a3ca12efed64ca85d5000ebd6adfbcc673e73c51557d0a5317af4e803070ec427a4",
        b"1d04d6382337df681a917792c9bfd45fe9b82e473f6c0cf2cfa2ba425e510fef672d715da178a41e",
        b"5ec6ab2bf28d321e550f2f701a74dd15ed1d46e7f3fd2493e01e5b83f53a127957d1c8ccf934e998",
        b"3163cc71ba19a00b302abebfd512ca0fe8e1c18c6c5e48c6138afcad5228bc3ffee33fa67ba7ef7c",
        b"e73bd4ee8e3beeb8da4fb1b6f640916f9447e49d94f676c65fe9b82e26ff56907f16d515fa9c730f",
        b"efa7b5ae503c520f2fe3d515f946d17afdbcc069d07557b477189dcff7132b857a6c0d4c6f77f4ae",
        b"a29199f39f7ffe797afcecb3cf1a130ab5f1a82efd2d115b7e3fa0870733b27921194f28fa4c7e29",
        b"74fb4425b46ddb36ea27f420f19adada03dd7da399b38bdc64d2deceb8121cd795e9694d80fcb3a8",
        b"aef8deeeeefd447585e2917a7819af6e24f18da2f5fa7981d3a0ebae68ef303a9fef27698af6d81a",
        b"98deeee85d4523f3e74f9830e1aaabaea2d756f4b46b6e20ebd0df6202fa01a51eccc8e685643ca1",
        b"fcdae9a933532d67a09b049ac23cf5d3dd4ee2fd346b0f74f78d66ce5ea9de2ecabf15e49f4575c5",
        b"f77677ef27aa2b148fd4c3cb787523896f14add7cf0b6cc57add15ed1d46e7f3fd244dd11edbf834",
        b"c7de2e8d9f3fffd65b6f1d3162c4b469d3cc4f58a21cfdcd8f507e40a90733025e48e44b65d67ee0",
        b"c081d6d6d6f84c1e4af81ffee11f9ac7f3e7cf8fed33c80b89e294f6760fefa435ffd271a4eb42f9",
        b"4720ffacb5aef8deeeeefd64ea0ac523f5f0a27122896f9471ed797881ad58af3bbff145de61743e",
        b"d34fd214edb135b8f77669fcfcf9fbf7ef3faa172aeff8a0477ff326941f50eac134a4bd90c813ca",
        b"acfdd0a143279d74d292254b5ce2a42d887f4646198edfd4455e4814a7b4b77b7827adf9978e235d",
        b"17ca3f83d53f6bad2bbeb78bbc9f4c5d59e3f1f0f05ac73138fa4699deeee7054e83aebb3a7887ad",
        b"e733fdc44aa11e5b83a8b74be3e7cfefe8e8483c3b78f43745695c1ace8fd3477ca38aa228796894",
        b"deded77ca38aa228796894deded77ca38aa2288aa2288aa2288aa2288aa2288aa2288aa2288aa228",
        b"8aa2280a83d4432af584ba23f2729adfd92b4ece157cfcfc1eccfaf861d3f0fb22f5c0a68fd7c7c7",
        b"8a7c9d528f6771f5df1c84ca4f75eabf41f1f0904a3da1ee88bc9ca6f76edab4a98848828f1fc483",
        b"59073fac157e5f441e58ebf13af85891afd3c3e3595cfd370741f253a9fa6f50caf29032387a391b",
        b"abb707f16036c4be18d07a993c14ea6345bece3eebf1ac3815ac7f3fcaf2fd493da4c8fbf9ab5ffd",
        b"6ad6ac59c71d771c4d7ade79e765fe25383d1d7774740c1c3870d2a449f7de7befc489136bd539e9",
        b"6bdc9a9fd8ef3965ca14ca033d3bfffce73f37e74b7da3565f2433be351ef3c1d1f1df7552aee865",
        b"3e9f6784745fd07ad17ef97921d3fb22f5c0f279488f1f641f91af93f178227fa8349fd2eb0281c6",
        b"91f601a9bf559a7fa9471851cdfaf7a32cdf9fd4438abc9f0b162ca049299ec71f7ffca28b2ea279",
        b"f9f55232e9da79eaa9a768f6965e9765ede7c8a5af716b7ee2cfa4bdfbeebbe9ee9a0298306182f9",
        b"5440a96fd4ea8b64c6b7c6c3f4f6501e4cb42f68bd68bffcbc90e97d917a60f93ca4c70fb28fc8d7",
        b"c9783c913f549a4fe9758140e348fb80d4df2acdbfd4238ca866fd7b50aeefcfc3439a764c7ce52b",
        b"5fa13bf05ffffad751af4021bebf45d0d3ae790142d0ecbb77efaefddfc4358ef293f07b3ef1c413",
        b"2dbdfe2ca96f3441ec8b44e3a378685ed4dba3101ecc08ec4be67ad3fbe5e78544ef99b8fb6d99e3",
        b"e9f143eda3f9127d5676e6676827c68924f9945e1708eb38d23e20f5b77ae75fea11b652c1faf7a0",
        b"5cdf9f8787349d2b7acd48cf7db46594797aeacc9c74f2e4c94b972ea5253ff4d043fdfbf7af1561",
        b"47a96b1ce5c7f4de0d1b3698e3a6b5d29752df68047c91687c14cfe1c38799de9edf8319817dc95c",
        b"2faa6da91752d4dbd17a993c24c60fb58fe6bf44bd9d19c7ba5e944fe97581b08e23ed03527fab47",
        b"fe0d528fb0950ad6bf07e5fafe3c3ca4d66bd90476c515570c1c38f0cb5ffe323f29b574b305471f",
        b"7d74fa8723d6de9ece4fc2eff9ce3bef98de2bf58d225f241a1fc543dd9e1e50baccf1bbeebaabb6",
        b"b7e7f76046605f32d78b6a5bea2010f576b45e260f89f143eda3f95ff7dece8f635d2f9f4ff7eb82",
        b"27318eb40f48fdadd2fcc7485d93562a58ff1e94ebfbf3f090a673f5a31ffd287e6c9e4fe9269699",
        b"74c68c195d5d5d14a7f5b4c4358ef2637aef8d37de688e9b1f3dd32b1da96f14f922d1f8cc7eb5b6",
        b"b6d2b79be38b162daaededf93d9811d897ccf596d2dbd17a993c24c60fb58fe64bf7dece8f1349f2",
        b"29bd2e10d671a47d40ea6f95e63f26486faf60fdfb51a2ef4fe421b57a3fe9bf4e38e184f9f3e76f",
        b"dab4e9a9a79e9a3d7b36bd98e2a5d8edededf3e6cddbb66d1b0d52fb868cd5cb89f2637a2f4dbd6e",
        b"ddba2d5bb68c1b37eeacb3cee2f36305f92299f1d17ecd9933875e5e757777af5ebd7ae8d0a1b5bd",
        b"3d880713ed0b5a2ff2b44aeb04ed8bd4038b8ea3f183eca3f95ff7dece8c23ca277f5d1c3c78904a",
        b"68c1820599c967c691f601a9bf55eaedf5f011232a55ff7928d7f7e7ee2145de4f6a7de6fd407ac1",
        b"480d9091921b162f5e3c6ad4283ad98c13dfad212fa7353fd47b6984eddbb753d7a507175c7041fc",
        b"bb6a52dfa8d517c98c8ff68b9e88a74f9f3e68d020cac6fdf7df4f2da2f60febf27b30d1bea0f5a2",
        b"fd92d609da17a907161d47e307d947f35fa2f7dbd138d27c32d705f576ea7883070fe657c48f23ed",
        b"03527fab34ff1e3e6286ead4bfe2c8e6cd9bdbdadacc8d07fdfbcc33cf509e5f7ef9e5b2e35294ba",
        b"b27cf9f2f8b7f814a509e8eaea6a6d6d5dbd7af5ce9d3b9f7efa697af14b772f6fbcf146d971294a",
        b"fd78f3cd37c78e1dbb75ebd6b2035194601c397264e5ca9574eb4e2f30e965e6d4a9536b7f54a428",
        b"7d81975e7a29feb5404551144551144551144551144551144551144551144551144551942640fd80",
        b"d544ead36cd67dac5a3c65e1ee812d9a4b2eb9a4f6ef2e13ae13693c8db2bf893819af717d3cbc99",
        b"a81fb09a487d9a4dbc8f558ba714441ed8a2a1e9f6ecd9336edcb8050b16245c271ef134cafe26e2",
        b"64dc9775f0f0bad0347ec02643ead3d47d6c6e3c3cb04573c61967509556279e3a93e9352ed4c39b",
        b"49d5fc80c81789bc8dd6e38c630ec583e6657c8bebd7af6f6f6f1f3060405b5bdb9a356bf8fc20ac",
        b"fe53c6a789a8da3e5ac7a767198a81f23c72e4c8279f7c72c28409f460dfbe7db11ff6cc33cf349f",
        b"49157fcead349e20f92fda178cf210b17568dd5f743c94d79827dddba57ede201e64a67eacfbcb8c",
        b"8f8e5be364bcc686fc1ede3c54cd0f887c91c8db683d9ed9dbd3f1a079916fb1b3b3b37ffffe2b56",
        b"acd8b163c7edb7df4e9560ca49ea79b4fa4f199f26a26afb681d9f7a5a4bafa376f2e4c943860c79",
        b"f8e1874f3df5d49b6fbed95c23a3468dbae38e3b9e78e2894f7ef29363c78e35377ed27882e4bf68",
        b"5f30ca4384eb50ea810de535e649f776a99f37880799a91febfe32e3a3e3d63819afb121bf873727",
        b"95f503d6fa2291ff11f91cf9decec7533bafd5b74897f989279eb86cd9b2f85bcce77e4b3d8f7bb0",
        b"af3672f06926a8ce3ea2f1a9a751fdd3116a5fe79e7b2e3da0dabee69a6b127e58ca007d491d551a",
        b"4fc0fc17ea0b4679489c96f0a5ba7b60c37a8d19acefc948fdbc516e0f32aa1f667f45fd04c589bc",
        b"c6f109613dbc1e54ca0f887c91c8ff683dcef843513c685eab6f915e3ed3031a2a3188d4f3c8f86a",
        b"23796fafce3ea2f1a9a75137a013aebefa6a7a411af5163f3d36d7c8ba75ebccb7d39dcfd1471f7d",
        b"e79d774ae30998ff427dc1280f11eb4b75f7c086f51a33587bbbd4cf1be5f620a3fa61f657d44f50",
        b"9cc86b1c9f90dfc39b93eaf801337d91c8ff9838cef843adf130f35a3fdbdff4f6f4a7a44a3d8fbc",
        b"af56dadbabb38f687cbeb7c77e5882aecd55ab5649e3099bffe27cc1280f7cfdbb7b60c37a8d19ac",
        b"bd5deae78d727b9051fdf0fbcb8c8f8e5b7b7bda6b1c9f90d3c39b9feaf801195f24f23fa2e3c81f",
        b"6a8d8799d7dadb09ba97a3dd8f4730be0fa9e791f7d54a7b7b75f6118dcff7f6f8fd6df352baf665",
        b"91633c61f35f9c2f18e581f7a5ba7b60bde3a49b225e4999c0dadba57ede28b70719d50fb3bfd27e",
        b"628d13798de313727a78f3531d3f20f245226f23e37344fe506b3c8ca71239b96858fa162a6cba1e",
        b"291bededed3d3d3d4c7e108caf56dadbabb38f687cbeb753aaefbffffeef7ffffb74cef8f1e37ff7",
        b"bbdf79c41330ffc5f982511e78efaac803eb11e7810307e88e283363061aa1f6f7db2957f17f89fc",
        b"bc413cc84cfd58f7d7a39f58e364bcc6413cbc41a88e1f10f92291b7111d47fe50140f9a97f12dae",
        b"5dbbf6b4d34ea36f1933664cfc0682d4f3c8f86aa5bd3daad23e5ac7e77bfb2db7dc72fae9a70f18",
        b"30e0dc73cf8dfff2451a4fc0fc4785f98299f7db19ef6a24f1c07ac479e8d0216a654b962c7159c2",
        b"9429536af7e56b5ffb5aedffbafb7983789099fa41fb2bed27d63819af71280fafa23434e6da8c7f",
        b"f6ad2822b47e14a59ae8b5a9e441eb4751aa895e9b4a1eb47e144551144551144551144551144551",
        b"14455114455114455114452994b23c83a1fca152ff63a8791152bfa4d4bb1a8a723d984f3df51415",
        b"521ef704a2e8fd45348a57342cf9f7b1acfdea0b94e2190ce50f95fa1f037a4b1122bfa4d4bb1a90",
        b"723d98a6271c3c7830ecb075d85f44a37845c392731f4bdcaf3e487d3c83a1fca152ff63d5bca552",
        b"ef6ad350506fafdafe363d39f7b16fee57137b06a5fe50a9a732d4bcd27521bfa4d5eb8abcab8c73",
        b"10ed23aa07e4df4471a23c5b61e2441e5bea00175d741145424f67e633724d4f08e50f2d747f198f",
        b"2aca6704bcbd685dd2eb1a8d6f1d87e927d23a47fb88e247147d3d569626f60c4afda1524f65a879",
        b"a5eb427e49abd7157957999e89f611d503f26fa238519eadf0bdddeab1ede8e8183f7efc962d5b28",
        b"1ebafce9dbcdc7b186f28716babf8c4715e513797bd1baa4d7351adf3a0ed34fa4758ef611c55fca",
        b"7e5599e6f60cbafb4313387a2af3cfebed4f4cbb0cac5e5743fab382199fac751f997ae0fd9bc8a7",
        b"6348e4390d13a775bd7bf7eea5f3e925bc39be6cd932d313c2fa438bdbdf4c8f6a229fc8db8bd625",
        b"bdaed1f8681cd44fa47940fbc8c4cf5087ebb18234b767d0dd1f1a79792af3cfebed4fb4f6f6b4d7",
        b"d57c99eeed8c4fd6ba8f4c3df0fecd749c4c9ed330715ad7fbd8638fd183b7df7ebbf638ad28ac3f",
        b"b4b8fd653ed7dd90c827f2f6a27549af6b343e1a07f513691ed03ef27e61441daec70ad2dc9e4177",
        b"7fa89fa732ffbcdefe446b6f470e91746f677cb286c43e32f5c03b29127166fa701330715ad76b7e",
        b"2322bed17af0c1074d4f08eb0f2d6e7ffd7a7bdadb8bd625bdaed1f8681cd44fa47940fb9819bf95",
        b"3a5c8f15a4b93d83eefe503f4f65fe79bdfd89397b7b847db2d67d64ea41d4dbf93c5b41715ad74b",
        b"2f01e8c1a38f3e1a2f9cbea4570aa13ca786e2f657dadb91b717ad4b7a5da3f1d138a89f48f380f6",
        b"91f7db22ea703d5690e6f60cbafb43fd3c95f9e7f55817f2874a7bbbd527cbec23f28aa2de688d93",
        b"cfb315e4bd45eb9d3163c629a79c42377e545a9473d313983c7bf4f6e2f697e9ed68df91b717ad4b",
        b"745d33e35bc761fa89b4ced13e327edbfaef5795697acfa0bb3fd4cf53997f5ee9ba905f52dadb91",
        b"4f16ed23aa07d443509c7c9ed3a038d17a0f1d3a346bd62c3a9fbad07df7dd17bf4c08e2398d2968",
        b"7f99de8ef219016f2f5a97f4ba46e35bc761fa89b4ced13ef27e5b4471d76365515f89a228a1d07e",
        b"521d742f14450985f693eaa07ba1284a28b49f288aa2288aa2288aa2288aa2288aa2288aa2288aa2",
        b"288aa2288a520a7dc427f8f8e38fb7d4785adf7df75dfa32fda9958a94fad70f3f7e7ebfad1ff5cf",
        b"838b5fb8386f6c7eca8dbf2c8f70dde83b3e41d3db630fc87befbdd752f331d18a1fa5d40f337e10",
        b"bfad07a5e4c1c52f5c905b300825c65fa247b86ef41d9fa0e9edef7bdffbbefbddef46bd1f39abbd",
        b"3d3fa5d40f337e10bfad07255e47bc5fb8cabddd504afc4def112eda27883c8c566f26e38b0ce231",
        b"a4de4e8dfd0b5ff802cd42b7ee3466dcdba51e46743ef2784ae3a7dbbf8e8e8e8103074e9a34e9de",
        b"7bef9d3871e2f5d75f8ff2663e2439ce6d4f4f0f7db96bd72e8f79453ed3485e3fd6bc31ee3c9407",
        b"347e28bf6dd5bc9c7c3ce9de58a837f6fcf3cfbfe9a69be8c1ebafbf6e2ae4861b6e9833670e1327",
        b"3fbe7bfc8cd7d53d6fc823cc609d97f1c332d791d53f5b84a7b5689f20f2305abd998c2f3288c7d0",
        b"f4f6bd7bf7d26bb1471e79e477bffb5ddcdba51e46743ef2784ae3a7e2a7daa0d8682893135336d6",
        b"bcd1f3d4c9279f1c7f6e7677773765cf7c2ea2745e91cf3492d78f356f4c6f477940e387f2db56cd",
        b"cbc9c793ee8d857a63e98ef7e28b2f8e7adfaf369f824b3573dd75d73171f2e3bbc78ffa89286fc8",
        b"23cc609d97f1c3a2eb08f9670bf2b416ea13e43daa86d89b897c91a13c86a6b7d383f9f3e77fe213",
        b"9f887bbbd4c3c89c6ff5787ac44fb779e6c69ba0ddd9bd7b77fa9c5adf28758f3163c698e30b172e",
        b"fce217bfe8372f1a9fc1bd7e50de182f2aca03e3bdcdefb7ad9a9733339e446f2cda1bbb61c30673",
        b"9dd2d32eddc9d0adc5dcb9736975de5e5dc7f823b77ee29837eb675f23acf3223f6ce27be3eb08f9",
        b"678bf3b416ea13441e55ab37137d7e75288f61dcdb5f78e10573eb6e4a48ea6164ceb77a3c3de2a7",
        b"572e4b972ea5291e7ae821cacf81030798bcd1f1e79f7fbea5d7274eb70d74a3482b8dbc3cb3229f",
        b"a9c1bd7e50de182f2aca03f2dea27844f157cdcb99194fa23716ed8d7df1c517a93c687c7ab5387a",
        b"f4687ac29d32650add637b7b751de38fb2bccca2bc897abb755ee4878dc07584fcb3c5795aebe013",
        b"4c7818913713f5f6501ec3b8b71334fee9a79f5edbdbdd3d8cccf956678447fcd4cacc1653b5c41b",
        b"c1fb46274c9870d55557d13d155d6ee61781a4f34a7da606f7fa417963bca8d63ca0f1997844f157",
        b"cdcb99194fa23716ed8da51b57ba961f78e001ba6fa71bda5b6eb9859ad8abafbeeaedd5758c3f3e",
        b"017999457913f576ebbcc80f8bae23e49f2dced35aa84fd0ea6144de4cd4db33e7a5e6109b22196a",
        b"7b3bdd42f4ebd7cff476a9879139dfdadb3df246574d5757175d0bb5da59de377aebadb78e183162",
        b"dab469e6271491dc33ebe1338d24f5c3e40d7951ad7940e333f188e2af9a9733339e446fac833796",
        b"aed3b3cf3e9b5eaad05d2bddb40f1932846e27bcbdba8ef147595ee6047cde44bddd3a2ff2c3a2eb",
        b"08f9678bf3b416e713441e46e4cd649c62ccbcf43a9d3a838bd9b0b6b747bd2ece96ffffb69ed4c3",
        b"88ce47ae37a987b1bdbd7ddebc79dbb66da38289df88e07da3fbf7ef3faa172ab9781cd1bc1e3ed3",
        b"48583f286fc88b6acd03333e8a471a7fd5bc9c281ee4172eda1b7bd96597996be7b5d75ea37ba489",
        b"1327f271a2f145f1335e5769de22496f47f3223f2c731d21ff6c719ed6e27c82c8c368f56632bd9d",
        b"99f7d0a14394ea254b96642e33d1db7ffad39f52599ade2ef530a2f3516f97e66df1e2c5f43a9792",
        b"66de9188ef6a78df68474747a20b49e795fa4c0deef583f286bca8280f4c6fb7c6238dbf6a5e4e14",
        b"0ff20b17ed8da57bd101030698358e1b37eed24b2fe5e344e34be367bcaea2bc45c2fb76ebbc8c1f",
        b"96b98eacfed9a6f1b42a3c9b376f6e6b6b333724f4ef33cf3c43b5f1f2cb2f971d57bdd13c285546",
        b"3d538a94aeaeaed6d6567af9b673e74e7aed462fee060f1efcc61b6f941d57bdd13c2855467bbb22",
        b"e5c891232b57aea45b567a01482f03a74e9d5afba39cbe83e641a932dadb15455114455114455114",
        b"45511445511445511445511445511445513c70f73c56d97b5b658f677d6874cf2c42ea21adbeafd9",
        b"c5ebea4ea83c2b4d86c8f358653762f55d6f85d2e89e5984d443da10be6617afab23a1f2ac341f22",
        b"cf63d5ae915afa786f6f74cf2c42ea216d205f33ef757524549e33a99a07108d2ff524a2f3a5be4e",
        b"c6f3285a6f599e47abaf13ad97f1d5a27d417e5804f2604ac7471ed5203e50063f1f689a46f7cc86",
        b"aacf209e59a66e45f14759f59ce8ed2fbcf0424b8d1f6aebd6adfdfaf5e33f1323949fd785aa7900",
        b"d1f8524f223a5feaeb449e47e97acbf23c5a7d9d4c6f6f01be5ab42fc80f8b401e4ce9f8c8a31ac4",
        b"07cae0e7034dd3e89ed950f519c433cbd4ad28fe28ab9ed3f7edf4d4b970e142f398c2883fc752ba",
        b"5ea99fd7852a7b006b7d9d224f223adfc3d769f53c7aacb72ccf23f275a2de6ef5d526c6acdd17ab",
        b"1f16c17830a5e35b3daaa17ca0086f1fa895c6f5cc06ac4f34afc833eb58b72ef1f3f59ceeedab56",
        b"ada250cd7defcc9933cd8b23e97afdfcbc9954cd03887c9d224f223adfc3d769f53c7aacb72ccfa3",
        b"d5d789d6cb7c7e3eda17ab1f1605c37830a5e35b3daaa17ca0086f1fa895c6f5cc06ac4f511ed0fe",
        b"32752b8d9fafe7746fefe9e9a1e71dda02aaea8103073ef7dc731eebf5f3f33a52110f60a6afd3d1",
        b"9388cef7f0755a9d02deebadbfe7d1ea8640eb45d708b32fc845620579303dc6b77a5443f94011de",
        b"3e502b8deb990deb21cdef99f5ebedeebee3f81bad3f4b9d3d7bf6dcb973e909c8317ba1fcbc9954",
        b"ca03c8f83a459e4474be87afd37acd7aacb72ccf23ba96adeb45d708b32fa2de8e3c981ee35b3daa",
        b"017da056bc7da0561ad7331bb03ed1bc22cfacb4b74b7dc7f1375a7b3bd5f3a04183a8c333ef02f1",
        b"ebf5f3f3f254cd0388c6977a1299f3a5be4e74cd8ad65b96e731c2d7b275bde81a61f65dd4db23e0",
        b"c1f4181f79543d7ca0070f1ea4542f58b0c0259f521f2843437b6643d5a7340fd6fd95f676267e54",
        b"6fc8eb1af5bedb40777a74e6ce9d3bbdd7ebe1e7cda46a1e4034bed49388ce97fa3a996b56b4deb2",
        b"3c8fe81ab1ae97b946d0be487b3bf2604ac7471e550f1f28f5769a65f0e0c12ef994fa40791ad733",
        b"1baa3ea579b0eeaf476f97fa8e91d7d5b074e952caf6912347bcd7ebe7e7f5407d224a9509ee51a5",
        b"d75ff16fd93501ea99ad338b162dbaf2ca2bcb8ec209eded4a9509eb517df3cd37c78e1d9bfec978",
        b"e3a29ed9fab07dfb76bab7dfb87123bd1ecffc6bc48aa0bd5da932613daa2fbdf452fc6b6fcd817a",
        b"66eb0335f6e1c3870f1b36acb3b3b3ec581445511445511445511445511445511445511445511445",
        b"5114a54f13d6df97f6605e74d145f3e7cfcf3f72a87110457b1bf9f8ebef0f75f75af2be48b42ea9",
        b"37b36a54dfe3c953f4f52225118ff95d6bab742fac9fb4cf12dcdf9776a54d9f3e3dd3cae142a871",
        b"acd4c1dbc8c75f67c79cc86bc9fb22adeb927a33ab4643783c790abd5e3c48c4637afba64d9bd267",
        b"06f493f66582fbfb1ad48359bab7b1ce79937a2d23a12fd263fc4a517a3d343d4c6f3704f193f659",
        b"42f9fb9007f39e7bee31239f7df6d9b5e75bfda18cf750340e735c9a0791b79101c58ff286c6677c",
        b"b55642792d0de96bcdba2e667c51de90338ef1f9fa7930d394e5f10ce50bb6ee0b8ac7239fd2ebce",
        b"1a4f3cef942953286f74579ff091a5eb4d7add85f2db3622a1fc7dc883d9d3d343c3d2b7277a9ad5",
        b"1fca780f45e330c7a57910791b1950fc286f687ce4154584f25a1aacde99f4ba98f14579e37bbbd5",
        b"e7ebe7c14c5396c733942fd8ba2f281e8f7c4aaf3b6b3cf16789df7df7dd74f74edf484f37b59fa6",
        b"98ae37e97517ca6fdba0e4f7f7657a30bff8c52f267a9ad51f9ae93d741c87392eca4324f436664e",
        b"91881fe5cd71fc5aafa895b05ecb08bf464eef8b757c69de900f14f97cbd3d9856eaeff14c90c717",
        b"6c48ec0b8ac7239f7ed75d229ec4bcf4b4425f3efbecb3f109897a93d64f58bf6d2392dfdfc77830",
        b"0de96bdfea0fcdfc1c66c77198e3a23c44426f63e61489f851de98f19157d44a58af6594bbb74bf3",
        b"867ca0c8e7ebedc1b4527f8f6714ce176c48f7766b3c1ef9f4bbeeacbd7dc3860de64bf3541e7f19",
        b"a5ea4d5a3f61fdb68d487e7f1ff260c62758affd28e50ff5e8edd671328f5bc9ef6dcc9c22113fca",
        b"1b1a3fd3279b20acd732cadddba579433e50e4f3f5f6605aa9bfc733b82f58d4db45f9e4e341c7ad",
        b"bd3d9ef79d77dee17bbbb47ec2fa6d1b91fcfe3ee4c18c4f485ffb567fa8476f471e52a95fd59a87",
        b"48e86dcc24113fca1b1a9ff18a5a09ebb58c72f7768fbc597da0c8e7ebedc1b4527f8f67405fb041",
        b"d4db45f9f4bbeeacbdfdc61b6f345f3ef9e493f4e5f3cf3f1f9f90a83769fd84f5db362241fc7d56",
        b"0f66d4fb1ad3fc0c858a8a1e9837e1913f94b91644e378f849511e44de46066bfc4cdeace3335e51",
        b"4428af25f245a275a1f1a579b3fa4091cf9759af476fafbfc733942f3802fbc2f776f77c7a5c77d6",
        b"78ccbcf42d54fc5bb66c19376edc59679d65e247f526ad9f807edb0625bfbf0f7930e9856ded9b63",
        b"b7dd769b39dfea0f65ae05d138cc71691e44de4606143fca1b1a9ff1d55a09e5b544be48b42e34be",
        b"346f561f28e3f3957a3079eaeff10ce50bb6ee0bdfdb45f9945e77d678685e3a6dfbf6edd4d5e9c1",
        b"05175c10bf918bea4d5a3f61fdb68aa2148a7ac1c2a2f95414a50a682f0a8be65351942aa0bd282c",
        b"9a4f455114455114455114455114455114455114455114455114455194a8ee7e46c6b7283dbf683f",
        b"e325975c52fb7776b1ebc120f5d556dc835937c27a7e8b00d55573f840a53edc46f1cfbad75573ec",
        b"a30b75f633663ab9dccf2fdacff8eaabafd2f8e3c68d5bb06041adeb21f2f2d556dc83591f827b7e",
        b"8b00d55513f840a53edc46f1cf8aeaaa09f6b19a04eced86a2fd8c679c71c6f2e5cb130783fb6afb",
        b"080d943754570ded0395fa701bc53feb5157d5dcc7503ec1507e4634af354ec6b768f54ed6c1cfc8",
        b"93eeedc8cb89907a6319d6af5fdfdede3e60c080b6b6b6356bd644d86117e17d41f158f78b193f94",
        b"df56eaf945eb62f63d9db728cb639bbfb7a3fc58d7cb785a83f8463d7cbb85fa883dd68bfcb9284e",
        b"bffd2d97503ec1507e4634af354ec6b768f54ed6c1cfc893eeedc8cb29ca7324f769767676f6efdf",
        b"7fc58a15f482faf6db6fa78e414faf99bd3dbd2f281eeb7e31e387f2db4a3dbf685d68dfad798bb2",
        b"3cb6f97b3bca8f75bd8ca735886fd4c3b75ba88fd863bdc89f8be2f4dbdf1209ee13cce96744f3a2",
        b"38337d8b86d83b59b49f3113eb7b32562f278fbb37d60addcc9c78e289cb962d8b8f98cfc7467ed2",
        b"28ab1e12f1a0fd62c60fe2b7957a7ed1bad0bea3bca5c74c786cf3f7766b7ed07ad17517d0371ac9",
        b"dd2ec5f9883dd6cbf87333af47f7fd2d91e03ec19c7e46342f8a93f12d5abd9345fb1933b1f676ab",
        b"9793c7dd1b6b855eaeb6f48a7512c7919f34caaa87443c68bf98f183f86da59e5fb42eb4ef286f51",
        b"96c736c87b32e9fca0f5a2eb2ea06f3492f7f6e27cc41eeb65fcb9d638fdf6b74482fb0473fa19d1",
        b"bc284ee45b44dec9a2fd8c99587bbbd5cbc923f5c626303d6aebd6ad89e3c84f1a65d583b5b7a7f7",
        b"8b195f14bf21bfe717ad0bed3bca5ba6e734d4cf5213f941eb45d75d40df6824efedc5f9883dd6cb",
        b"b85ad2717aef6f8904f709e6f433a279519cc8b788bc93c1fd8cd4ac32557db5587bbbd5cbc9e3ee",
        b"8db542653c6cd830ea12f1917815563f6924eced4c5da1f183f86da59e5fb42eb4ef286f991edbfc",
        b"bddd9a1fb45e74dd05f48d46f2de5e9c8fd863bd4c6f4fc7e9bdbfe512ca2718cacf88e6b5c6897c",
        b"8bc83b19d6cf78e0c001ea5499c64603ada8f6f7dbf7efdf1fff97d5cb29cab3874f73f5ead59422",
        b"7aa2a1baa5d5b5b7b7f7f4f444c04fcaec0bf2a5a2bab28e1fd06f2bf5fca275a17db7e68df1d8a2",
        b"ba42c7ad30f9b1ae9771f985f28d46f2de5e9c8fd863bd4c6f4fc7e9b1bf5520944f30949f11cd6b",
        b"8d93f12d5abd9361fd8c870e1da24b6cc992252ef99932654aedf85ffbdad76aff37ede514e539f2",
        b"f2c3ae5dbb969649291a33668c79432c027ed208ef0b8a07d5151a3f94df56eaf945eb62f6dd9a37",
        b"e4394575858e23507eaceb657a5d28df6824efed51613e628ff5f2fedc749cd2fdedb3a8e7455114",
        b"a5f9d0deae288ad27c686f5714455114455114455114455114455114455114455114455114455114",
        b"a55214e719147915333daac8ef59b47fb339fc924f3df514a59777b584c56f5fa471d67f5d8875eb",
        b"d6ad5fbf3e7dbc2c3fac74deaa796c8bf311f7115f6aa19e41917b2bd39d67f57b16eddf6c1abfa4",
        b"e981070f1eaccf74defb228db3ceeb62983d7b36b597c4c1b2fcb0d279abe6b12dd447dc477ca985",
        b"7a06c3f6762b45fb379bc62f59e71ee8bd2f0ddadbdf7efbed41bdd083dae365f961a5f356cd635b",
        b"87782af839900de419445e45a91715f93d51fc528f67597e49e40945f14bbd99d4f1e84e9206a1a7",
        b"27f319a7a6075ac7617cb8a81e90b714e501c58fe294aecb1ae70b2fbc4027d05380f9dead5bb7f6",
        b"ebd7ef8d37de60f2ecc1c30f3f4c8b1a306040ed2b3b915797b9aea57522f5f94af70bedbbd4632b",
        b"8d5feaff6d385f6a037906915751ea45457e4f14bfd4e359965f12794251fc526f664747c7f8f1e3",
        b"b76cd9421d9bda02a5d77c9caf751cc6878bea01794b511e50fc284ee9ba509c93264d5ab870a179",
        b"4c974ffcb97fd23a61983b77eebc79f33ef7b9cfd1bff141915797b9aea57522f5f94af70bedbbd4",
        b"632b8d5feaff6d385f6a037906ad5e45347ea617d5ea2db2c62ff27896e59764e6b5c62ff551eedd",
        b"bbb7f67e75d9b265a607a271181f6e2db5f5c0f858d37940f3a238a5eb62e25cb56a156d81799e9a",
        b"3973e6f5d75f6fcef1f0bd5aa185d32bb2471e7964fdfaf5f480cf03025dd7d23a91ce8bce67ea0d",
        b"edbbc863eb11bfc8ff9bfedeeafb521bc83368f52aa2f133bda8d6bdb3c62ff27896e59764e6b5c6",
        b"2ff5513ef6d8637442fcf6afd9771a198dc3f870513d303ed6741ed0bc284ee9ba9838e9be8e9e4f",
        b"a93dd2770d1c38f0b9e79e33dfebe17b4521514b7ff7dd77691369fcdacfd373f7eaa2eb5a5a27d2",
        b"79d1f94cbda17d17796c3de217f97fa306f4a5369067d0fa19fede5e546b6f67bca58e1ecfb2fc92",
        b"999ed044fc521fa5f94d83f8c6fec1071f343d108d837cb84c3d302e98741ed0bc284ee9baf8ba9d",
        b"3d7bf6dcb973e98935bd3b22dfab954b2fbd94ee45dfdf4bbf7efda850993c20f8deee5e27d279d1",
        b"f94cbda17d17796c3de21739221bd197da409e416b4ff3f6a25a7bbbd5e728f27896e59764e6b5c6",
        b"2ff551d22d0a7de3a38f3e1a2f84bea43b19340ef2e132f5c05c6be93ca079519cd275f1754be70f",
        b"1a34883afc35d75c130fc5d789a357977ac8f1c71f7ff7dd77ffa297db6ebb8dbe8c7fc1c3ddab8b",
        b"ae6b699d48e745e733f526eaedcc38d2f845bdbd117da90de419b4f6340f2f2af27b5ae3f7f07896",
        b"e597b4cecbc42ff566ce9831e394534ea11b5d4a29c510f74ceb38c887cbd40373ad59f380e24771",
        b"8ad6c5c419f576e061c386d1919d3b779a237c9db87b75bbbbbb8f39e698b82951241446fc0e83bb",
        b"5797b9aea575229a97391fed97a8b7a3713ce217f97f1bd197da409e41d4d3a45e54e4f744f14b3d",
        b"9e65f925d1bc287ea937f3d0a143b366cda2fbd5f6f6f6fbeebb2fbe8db18ec3f870513df0f751e9",
        b"3ca0f8519cd275a1380d4b972e1d356a94f9cd2b3ecf91c4abfbd5af7e959e6b6a8f4c9932850e32",
        b"79b0c25cd7d23a11cdcb9c8ff64bdadbd138d2f8a5fe5ff5a52a4ad407bc5a8b162dbaf2ca2bcb8e",
        b"425114a5ae346b6fa75782f45a75e3c68d747f98e7af931445511a9166ededd4d8870f1f3e6cd8b0",
        b"cececeb26351144551144551144551144551144551144551144551144551144551fe17f51b968bd4",
        b"a32ac53d3fb5b8fb43abe9754de39e073e7ec7faccf4f686a251f25f71eeb9e79e61c386993ff48e",
        b"7a3f2bf8d4534f8dff0cbf1151bf61b9483daa1eb8e7a71647c75c65bdae69dcf3c0c4ef5e9f7e6e",
        b"47290d94ff8a63a44bf1679199cf1c6be8deae7ec372917a54eb86636fafacd7350f4cfceef5599f",
        b"dede94f92f05d3db3ffef18f9b2fa74e9ddad0bd5dfd860c017db256188f2a8a9f197ffdfaf5eded",
        b"ed03060c686b6b5bb3668d3988f213ca372af5ba4aeb4ae47565f60be5816e773b3a3a060e1c3869",
        b"d2a47befbd77e2c48946a584e217f943196fafd4578b3ca745e75f9ae720d785f960f9f8ef9a69ef",
        b"8e3df6d888f5f032f9719f9726fa833ff883a14387fef0873f7ceeb9e76815742999de2ef5fc06f4",
        b"e77aa37e4386803e592b8c4715c58fc6efecececdfbfff8a152b76ecd871fbedb7534599b247f909",
        b"e51b957a5da57525f2ba32fb85f24017235db3f40a855661bed7e40dc52ff28732de5ea9af16794e",
        b"8bcebf34cf41ae0bbeb75b3dbc283fa27969a2d34e3b8d9edca9237de10b5fa06b9096607abbd4f3",
        b"1bd09f9b07f51b22c2fa6411999ffd5b1bbf757cba593af1c413972d5b167f4be273a413f909e51b",
        b"35b87b5da57525f5baa2fd427920e8b676d7ae5de631ad62f7eedd4cfccc7aad206faf745dbc87b7",
        b"b8fc238abe2e8c0413f5f6b48797c98f685ed3db69169a8e524a91c7bdbd1617cf6f287f6e4ed46f",
        b"8808eb9345587b3b8adf3a3ebd1c6ee9151ba12912f909e51b35b87b5da57525f5ba329f5b6ecd03",
        b"41779e4b972ea5ebf4a1871ea23c1f387080899f59af15e4ed95ae8bf7f016977f44d1d7c5e1c387",
        b"5b706f4f7b7899fc88e635bd9d1e5c7cf1c5e6339ce3de2ef5fc86f2e7e644fd8688b03e5944bab7",
        b"33f15bc737bd7debd6ad688a447e42f9460dee5e57695d49bdae1ebd9d5aba6941d4256a7ff8881c",
        b"2868bd5690b757ba2ede735a5cfe11455f17d4a5e9040adb7c79d75d77d5f6f6b48797c98f68deb8",
        b"b753cd1bfb95e9ed7e9edf28843f3727ea374484f5c922d2bd9d89df3a3e316cd830aaa2788484f8",
        b"2f919f50be5183bbd7555a5752afab476f9f316346575717cd9bd0e032bddddd1f8abcbdd275f11e",
        b"dee2f28fa8c375d1dada4a656f1e2f5ab4a8b6b7a73dbc4c7efc7a7b8ce9ed1e9e5f9167b938d46f",
        b"8808eb9345a47b3b133f1a7ff5ead5f42dcb972fa73aa4a8dadbdb7b7a7a507e98f8a5bed148e875",
        b"95d695c8ebcaec17ca03256adebc79dbb66da383f11b324cfc68bd56186fafd457cb78780bcdbf34",
        b"cfa1ae8b3973e68c1e3dbabbbb9b0a7be8d0a1b5bd3dede165f213a4b74b3dbf7c7f3b78f02085ba",
        b"60c1029754e747fd865682fb64ad58df6f47f133e3af5dbb969643df3266cc187aa1cae727946fd4",
        b"e0ee7595d695c8ebcaec17cac3e2c58b478d1a4545688ec7afe698de6e5daf15c6db2bf5d5321e5e",
        b"6b3ca1f26fa50ed7c5fefdfba74f9f4e75485d823a39b5d677de7987f1f0a2fc04e9ed91dcf3cbf4",
        b"37eaed14d5e0c183b9142b8a9283cd9b37b7b5b5991b2afaf799679ea1ebf4e5975f2e3b2ec54ed3",
        b"f8bce8f575fc5ba98aa204a7abababb5b5955ef5efdcb9f3e9a79fa617dd7437f5c61b6f941d9762",
        b"a7397afb9b6fbe3976ec58e6371f1445c9c991234756ae5c49b7eef4c2995e3e4f9d3ab5f647604a",
        b"d5688edefed24b2fc5bf96a9288aa2288aa2288aa2288aa2288aa2288aa2288aa2288aa2284a1e9a",
        b"cf0f1853ae2f52ea270de54bf5f3a2ba13caab5b1dbf6735fdb93cee1edbaacd5b7f2f7323ee6f10",
        b"9acf0f1853ae534ce4270de84bf5f3a23a12caab5b29bf6705fdb99938ba0eab366f295ee646dcdf",
        b"2034991fb09606f24556d6979a2094c7b6827ecf4af9733369d0de5ea297b9b1f6370855f303323e",
        b"44a9e711f922adeb62e695ae0b7939adde46c6972a5d2f9a177924457ecc087b39d1f8d271447e4f",
        b"c6d789f68bf79326ae7df361bcf1f7f6f4f4d09746cf24f5ff22a43e5ca9c756ea9f45f158e77de1",
        b"85175a6afc5c5bb76eedd7af1fff590d41eae7fcf3cfbfe9a69be8c1ebafbf6e22bce1861be6cc99",
        b"c3accb60eded56bfb0351e0f3f2c82f73807a46a7e40c68728f53c225fa4755dccbcd275212fa7d5",
        b"dbc8f852a5eb45f3228fa4c88f19612f271a5f3a8ec8efc9f83ad17ef17ed2c4b57fe4c891934f3e",
        b"39fe9cf0eeee6e9ac57c7ea0d4ff8b90fa70a51e5ba97f16c583e69d3469d2c2850bcd39b41dfce7",
        b"a94681ea875ee15e7cf1c551efcfa7cca70753ccd75d771db32e43bab723bfb0351e0f3f2c82f738",
        b"07a46a7e40e443f4f03c32becbf4bad0bcdeeb4a3b20186f63fa337ebdbd968979198fa4c88f6948",
        b"7b39798fa7fb3891d0efc97851adfb95e9274d5ffbb42963c68c318fa9895162f971f2d47fa60fd7",
        b"c3639bc73f1bc7c3ccbb6ad52ada3273ff3373e64cba3fcc5c66fefad9b06183d977baf5a567407a",
        b"0a9e3b772e558b747f915f18c5e3e1877521ed710e48d5fc80c887e8e17944be4bebbad0bcdeebb2",
        b"f676e46d4cf7766faf65625ec62329f2631ad25e4edee3e93e4e24f47b329f1f6eddaf4c3f69bab7",
        b"3ffffcf32dbdde6a6a5ff482822e5b7e1c699d887cb81e1e5ba97fd61a0f332fbd4ea4e75f6a83f4",
        b"bf03070e7ceeb9e732979cbf7e5e7cf1450a8f66a45755a3478fdebd7bf7942953e83585747f915f",
        b"18c5e3e18745f01ee78054cd0f887c881e9e47ab9b00ad0bcdebbd2e6b6f478e80746ff7f65a5a7b",
        b"bbd52329723118d25e4edee3e93e4e24f47b66baf312fb95e927b5be1f3b61c284abaeba8aee15a9",
        b"8dd0d3bdcb388e7522f5e17a786c45fe59140f3fefecd9b3e9b6999e881dedb1f9eb875e10516e1f",
        b"78e001ba6fa7174ab7dc720b35c9575f7d55babfc82f8ce2f1f0c35ac9f43807a46a7e40e443f4f0",
        b"3c5a7b055a179ad77b5d397bbbb7d732312fe391f4e8ed692f27eff1741f2712fa3d99de6eddaf4c",
        b"3fa9b5b7df7aebad23468c98366d9a796735f2f5ffa691fa703d3cb622ff2c8a879f978e0f1a3488",
        b"3abc79372c9320f543fb4e154e2f01e85536ddb40f1932849e76a5fb8bfcc2281e0f3fac954c8f73",
        b"40aae607647c8852cfa3b557a075a179f97559415e4e516ff7582f9a1779243d7abbd5cbc9783c45",
        b"e388fc9ee85a63f60be593f1e7eedfbfffa85ea83cf87d91d689870f57eab115f96799789879cdbb",
        b"557464e7ce9dec86ff2f41eae7b2cb2e6be9fd11c06bafbdd6af5fbf89132732eb8af0fe22bfb035",
        b"1e0f3fac1526cfc1a99a1f90f1214a3d8fa85758d7c5cccb7b5dd3202fa7b4b74bd78be6451e498f",
        b"de1ed9bc9cbcc7d37d1c91df93b9d6d07ea17cf2fedc8e8e8e44b7f1f3ffa691fa70a51e5ba97f16",
        b"c5c3cfbb74e9d251a3469937ac5cc85f3f74af4b57a8f9de71e3c65d7ae9a5fcba98fdb5fa85adf1",
        b"78f8611128cf8d8ba31fb02caf4a73f85c14a5ce2c5ab4c8fc0e86d23771f7036a6f5794eab37dfb",
        b"767a4db171e3467a9dd2e8b79d4a1edcfd80dadb15a5fa50631f3e7cf8b061c33a3b3bcb8e455114",
        b"4551144551144551144551144551144551144551144551142518a17c9d457b3fcba2febe48439df3",
        b"d9d9d979f4d147efdfbfdf7cf9dbdffef6031ff880cbefc196959fa269143f6c286f6fa8711a05bf",
        b"ebab2cefad1fa17c9d857a3fcba2145fa4a1cef9a466fec10f7ef0eb5fffbaf9f281071e78fffbdf",
        b"9ff9196b25e6a7501ac50f1bcadb1bd0ffdb28f85d5f65b91195e094e88bac3f2b56ac38eeb8e3cc",
        b"c7717cea539fa26b3cf35b9a353f8de2870de5ed6d14ff6fe914dddb45fe3ec61b887c9dc823898e",
        b"4bbd9fc82f29f2bd7af81f912711c5837c91222f2ae375957a54fdbca2eef4f4f4d0c877dc71c7cf",
        b"7ef6339a9db623336fd6fc2098bab57a30517e505d49eb1611c40fcb402f073a3a3aa818264d9a44",
        b"853171e2c4ebafbfde7cf078fc77d65403c71e7b6ced77257a3be3ed4558f3e6318e359f4c9d4bf7",
        b"3d483d7bf43da9f736886f3a81c8dfc7780391af137924d171a9f713f925a5be57a9ff117912513c",
        b"c81729f2a2325e57a947d5cf2b2ae28a2baef8d0873e44ed6bead4a9997943f941a0fd451e4c941f",
        b"5457d2ba4504f1c332d09314f51cba2da159ccb549eb95f676c6db8bb0e6cd631c6b3e993a97ee7b",
        b"907af6e87b52ef6d10df3443a6bf8ff1541ad24e0ae491e4fd92eede4fc6436a5d17f2848afc8f8c",
        b"27918927ed8b947a5119afabc8a31af97a4545984fab26bef39def64aed79a1f47e2fd451ecc08e4",
        b"87a92bbfbab592df0fcb0c4eb7fdbb76ed328f6996ddbb779b7144bddd60fdac692bbce7d47d9c08",
        b"e493a9f35a32f73d543d7bf43da9f736886f3a81c8df97e9324baf11792479bfa4bbf7137948a5be",
        b"5791ff91f124325ed4b42f52ea4565bcae228f6ae4eb159542e5113f63668e6ff5a822acfb8b3c98",
        b"11c80f53577e756b25bf1f96199cee24972e5d4a4b78e8a187280f070e1ca083870f1f2eb4b7f39e",
        b"53516fb7e693a973d1be87aa678fbe27f5de06f14dd722f5f779acd1803c92e8b8bbf7d3ea32f0f3",
        b"bdbafb1f194f22e3e048fb22a55e54c6eb2a72edd50620f28a4af9dad7be666e7832d71b018faa15",
        b"b4bfc8831981fc64fa3aa5756b25bf1f96199c5aba69595409f180d475e9080d6bbebcebaebb8ae8",
        b"ed286fa2de6e48e413d5b974df43d5b35f6ff7f0dee6f44dd722f5f779ac11792479bfa4bbf7d39a",
        b"430fdf6b24f13f329e44a6b7a77d91522f2ae37595f6763faf28350d5e299820d1dbf9f1ad1e552b",
        b"687f91073302f961eacaaf6eddd725f2c332cc9831a3abab8bd69508a3b5b595d2621e2f5ab4286c",
        b"6fe73da7a2de6ecd27aa73e9be7be4d34aa8decef86783f8a66b91fafb98355a7d9dc823c9f825a5",
        b"de4f944391efd520f23f224f22d3dbadbe48911795f1c98a3caa1e5e51825eef53c7e08d900912bd",
        b"9d1fdf9a1f2bccfe220f26ca8fb5ae3cea9621bf1f968116386fdebc6ddbb6d1e69a37640c73e6cc",
        b"193d7a747777372564e8d0a1716f67fcb0a29ecc784eddc741f94475eeb1ef4c3edd3dced2be1709",
        b"bdb77e759589c8dfc7ac11f93a9147121d977a3f510ea5be5783bbff11791299de1ed97c91222f2a",
        b"e375957a54a55ed1a8579d4925b764c992cce4c4a47b3bef974ce707c1d4add58389f283ea4a5ab7",
        b"3c39fdb00c8b172fa68aa560ccfec677e3fbf7ef9f3e7d3abd0ea568a94352df337f18cbf84345bd",
        b"9df19c8ac6b1e693a973e9be33f974f7387bf43da9f7d6afae14772aee7f543f9452cbe6cd9bdbda",
        b"dacc0d1efdfbcc33cf5079bcfcf2cb65c79597bad5b9a3c759695c1ac5ffa8bd5da9a5abababb5b5",
        b"75f5ead53b77ee7cfae9a7afbdf65aba0be5ffe6ae21a84f9dbb7b9c95c6a551fc8fdadb955a8e1c",
        b"39b272e54aba75a717f2745b3275ead4da1fc9352ef5a973778fb3a2288aa2288aa2288aa2288aa2",
        b"288aa2288aa2288aa2288aa2280d4a591ec0507ec9aaf937ab168f94bee0856c4442d55575bcae3c",
        b"521f6ba3acab9e94e2010ce597ac9a7fb36af178a05ec80a12aaae2ae5756590fa581b655d0d41ce",
        b"6b39945fb26afecdaac55337b4b7174aa8baaaa0d7d58ad4c7da28eb0a4b053d8052bf24f22786f2",
        b"6f22cfa6d4c388e241be4e84f57cc6a186e2b752c17a40fb221d2754de42c55fb5ba925e7752cfac",
        b"745da17cac45fb6a2b4b053d8052bf24f22786f26f22cfa6d4c388e241be4e84f5fccc1e958edf4a",
        b"05eb01ed8b749c50790b157fd5ea4a7add493db3d27585f2b116edabad2cd5f400bafb2513247caf",
        b"f9fd9b11f06cfa7918d3f1f0dec934e87cc68fc97b541354b31e626af745344ec0bc858abf527585",
        b"c689c07527f5cc4ad715d0c72a5a57585f70b954d303e8ee978c58df6b7eff66043c9b7e1ec6743c",
        b"bc77320d3a9ff163f21ed50415ac07b42fa27102e62d54fc95aa2b344e04ae3ba96756baae803e56",
        b"d1ba82fb824ba49a1e4077bf24ef7bcdefdf8c80d3c1cfc3988e27d3d799009dcff83179174982aa",
        b"d543a6cfd7719ce079cb1f7fa5ea0a8d1381eb4eea9995ae2bac8fb5505f6d65a9a607d0dd2fc9fb",
        b"5ef3fb3723700dfa7918d3f1f0dec934ccf9c88f594a6f0f550fccbe88c60998b750f157aaaed038",
        b"11b8eea49e59e9ba02fa5845eb0ae557ad02d5f400bafb2579df6b10ff26bac6a55e4b140fe39db4",
        b"82ce477ecc50bdbd947a40fbe2515741f2162a7e347e545e5da17190fb4fe499f55857101fabc7ba",
        b"3cf25f4d2aeb0174f74bf2bed7fcfe4d740d4abd96281ec63b69059d8ffc98a17a7b59f580f6453a",
        b"4ea8bc858abf6a7585c641d79dd4332b5d57281fab745d7ef9571445511445511445511445511445",
        b"511445511445511445511445511445511445511445511445e96b14e413fce52f7fd9d2d29229bdca",
        b"4fd57c91657951dd7da6617d91528faa7b7e66cc9861fe12f6b39ffdaccb713faae6b1ad4f3cf5f4",
        b"d886dd2f1ef5f3c614e71334bd7dd3a64d39c7e1a99a2fb2442faabbcf34ac534ce45115e5e79557",
        b"5ed9b367cf39e79c93e809e8b80755f3d8d62d9e7aba0e03ee5726ea708c29ce27589fde5e355f64",
        b"4378514bf4457ae4e7c20b2fb4f60474bce8780aa56ef1d4bf0706d9af4cb4b71b0af5099ade7eef",
        b"bdf74e993285cea7bbbbd85383c691fa3151fc0de1698df373e699679acf568a3f0f16e507793691",
        b"cf14e501ad4b8ad4a38af2c3d7957b6f67c659bf7e7d7b7bfb800103dadadad6ac59c3c723aa9f27",
        b"9f7cb2a5e643ea7a7a7ae8cb5dbb7645e1ea19c1d4a1c863cb60cd1bf2a5f29e56f7de5e8775353d",
        b"85fa044defa2edb8fbeebbe9eefd231ff9c88409138e1c39c28c23f563a2f81bc2d36af2336ad4a8",
        b"3beeb8e389279ef8e4273f3976ec5873c386f2833c9bc8678af280d62545ea5145f9e1ebcabdb7a3",
        b"713a3b3bfbf7efbf62c58a1d3b76dc7efbedd404ccd36890faa1923ef9e4936fb8e106f3657777f7",
        b"902143cce76186aa67041a5feab145a0bc215f2aef6975efed45afab8f509c4fd0f4aec58b179b2f",
        b"a97dd197cf3efbace3388e7e4c6bfc0de1694de487ae6bfa923a03931fde7f9a7667a03cb8accb1d",
        b"478faa219d9fcc7a70eced681c6ab3279e78e2b265cbe233f7eeddcbc413c9eb879e25c78c19631e",
        b"2f5cb89012923e274f3dbb503bbed4636b05e50df94c333dad7eefc9045f57dfa1389fa0e95d1b36",
        b"6c305f1af5307dc98ce3e1c7b4c6df109e56939f75ebd6992fe9f6efe8a38fbef3ce3b99fcf0fed3",
        b"748f457940ebf2c3d1a36abe4ce727b3ae1c7b3b1a67dfbe7df48052670d3e48fd3cfffcf3e6be85",
        b"5e76d10b227a5a31c743d533028d2ff5d85a4179433ed34c4fab7b6f2f745d7d87e27c82a677d1ab",
        b"33f3e53befbc637a3b1ac7cf8fc978512bee694de487a0debe6ad52a26cfbc6b23dd630de93c2037",
        b"811f8eae3df3653a3f9975e5d8dbd138a6476dddbad51a7ca8fa993061c255575d45e53d7af468f3",
        b"c663f07a4ec08cefe7b14d80f2867ca6991e55c7de5ef4bafa0ec5f9044defbaf1c61bcd97e6474e",
        b"748783c6f1f3635ae36f084fabc94ffc3ead79494bdd9bc9b3b4b7a33c94d8dbd3f9c9ac2bc7de8e",
        b"c6a1a9e95e9aba687ca4568417aa7e6ebdf5d61123464c9b36ede69b6f364702d6b315667ca9c7d6",
        b"0aca1bf299667a5a1d7b7bd1ebea3b14e71334bdeb84134e58b76edd962d5bc68d1b77d6596799ff",
        b"b28ee3e7c74cc7df289ed6f867cdf7df7ffff7bffffd33ce3863fcf8f1e6bd0b9467d4dbad3e5326",
        b"0f4c6f3f78f0e0c89123172c58c0a78b9937627bbb353f68bd7bf7ee35bf173d75ea547a10bf4f8e",
        b"8ea37156af5e4d5bb67cf972ea1bf4bfededed3d3d3d281ebffad9bf7fff51bdd0b69a23a1ea19cd",
        b"c8d4a1c863cb2c0ae50df94cd171b45f65adabef50904f908a9c5e6f6edfbe9dba3a3db8e0820be2",
        b"174a681c3f3f663afe86f0b49ade7ecb2db79c7efae903060c38f7dc73e3bf5841f941bd1df94c51",
        b"1ef8de4e57d0e0c1835d3226f5a8a2fca0f57eec631fab1dffb4d34ee38f33f5b976ed5a3a8db66c",
        b"cc9831ab56adaa5d45a8fae9e8e84858a743d533028d2ff5d83258f3867ca6e838daaf12d7a528c5",
        b"617a7bfc7b05d581eed3bc7f2b525114a58f53cddefee69b6f8e1d3b16fde451511445e1a9666f7f",
        b"e9a597e25f335314455114455114455114455114455114455114455114455114455194a6a4f9bc84",
        b"45fb52a55ed1c6425a0feee74bf7a56a792ec8471c83d65bf4bc52aab62f0aa2c9dc5575f0a58abc",
        b"a20d87b41e1ccff7d8974ae5b9381f718c75bd7598574aa5f6456168b2dedea77ca94550506f2fce",
        b"e75b1fca8abfd1f3a6e4a4502fa1f900e7f8ef2eefb9e79e638f3d961fdfea917ce185175a6abc2a",
        b"5bb76eedd7afdf1b6fbc4155faf18f7f9ce21f3972e4934f3e3961c2047ab06fdf3ec6432af59c4a",
        b"bdb1681ce4158d808f520af2a8a238e976aea3a383923369d2244ad4c48913afbffe7a263f687c54",
        b"0f685ea9d752ba2f526f2c42eaf345f991c66fe5fcf3cfbfe9a69be8c1ebafbf6e66bce1861be6cc",
        b"99c3ac37c8bc4c1eacd72fe38d45715afdaa4cdf08b28fa89f30eb95ce5b050af512f2bddd3a3ef2",
        b"48520b5ab870a1794c2ddd7c8e1c3da0f1d7ae5d3b79f2e42143863cfcf0c3a79e7aeacd37dfcc78",
        b"48a59e53a937168d83bca2c84729057954519cd47ca847517953b42687665e941f343eaa0734afd4",
        b"6b29dd17a9371621f5f9a2fc48e3b7b27cf9f28b2fbe981e7cf39bdf349f5a4c315c77dd75cc7a83",
        b"cccbe4c17afd32de5814a7d5afcaf48d50fb68ed27ccf9d279ab46702fa191e8a1de6ef569228fe4",
        b"aa55aba82c4d7f9e3973a6b9c9a44da18447bda57eeeb9e7d203da8b6baeb906794899f546e1bcb1",
        b"8cef32e1b0e03d9e22ac1e55264eba6d3337540445bb7bf76eeb98717eace3a37a40f3fa792d3d3c",
        b"b6eede582b1e3e5fc663ebede18dd9b06183a9737a3aa68e4a2d74eedcb9f45dcc7a83cccbe4015d",
        b"bfbc37361127f2ab327d23d43e5afb0973be877fb9740af5121e3e7c98e9ed569f26f248d2f33ed5",
        b"210d45b30f1c38f0b9e79e8b7a7bfb19679c410faebefa6a7a0115f58a5de831f29032eb8dc27963",
        b"19df65a2b6798fa708ab479589935ee92c5dba94fad2430f3d44793870e080f916941febf8a81ed0",
        b"bc7e5e4b91c7d6e0ee8db5e2e1f3653cb61ef12778f1c517693aca1bdd158f1e3d9a9e88a74c9942",
        b"af7d98f5069997c903ba7e9137d61a27f2ab327d23d43e5afb0973be877fb95c8af612d2aed1098f",
        b"3cf288f9f2aebbeeaaeded8cbbc1ea919c3d7b36ddae5041c63649beb7a73da41e9e530f6f2ce3bb",
        b"b4f6f6209fa66b75763071524b37a54b998917c8e4c73a3eaa0734af9fd7d27d5fe2ff75f7c65af1",
        b"f0f932ae438ff813d08d22c5fcc0030fd07d3bdd40de72cb2df4e452fb0b30d6f5e69f97a91fe6fa",
        b"4d7b63519cc8afcaf48d38b03cfb68fe37dd4f32bdbd227f6eb9d4c14bd8dada4ac39ac78b162dca",
        b"eced8c4792e61d346810edc835d75c638ef0bd3ded21f5f09c7a786319df65fa3d19c6e329c2da5b",
        b"9838a94b747575d1f9b51a50263fd6f1513da079fdbc96eefb12ffafbb37d68a87cf97e9ed1ef1a7",
        b"a13aa715d1ad38bd1aa59bf6214386d4b64d6b6fcf3f2f533f4c6f4f7b63519c8c5f15f58d20fb68",
        b"48f713e67c0f7f6eb9d4c14b3867ce1c7afaeeeeee5ebd7af5d0a143f9dece7b24cdab3c3a935e3a",
        b"99237c6f4f7b483d3ca71ede58eb38c82bca783c45de52d45b509c34d1bc79f3b66ddb46c1c46fc8",
        b"30f941e3a37a40f37a782d45fb22f5c622443e5f263fd2f811975d76594bef8f2a5e7bedb57efdfa",
        b"4d9c38d11c4775156a5eb48f4c6f4f7b639938915fd5da3742eda321dd4fd0f9fcbca2ebb49e14ed",
        b"25a48d9e3e7d3a9d7fce39e750a7a51d377f2887c6e73d924b972ea557a3f11d0bdfdbad1e52a9e7",
        b"d4cf1b9b1e07794523ecf114794b516f41712e5ebc9832494936f1c4f679941f343eaa0734af9fd7",
        b"d27d5fa4de5884d4e7cbf47651fc08ba89a54a36df3b6edcb84b2fbdd41c67ea2ac8bc280ffc7baa",
        b"696f2c8a13f95551df08b58f86443f61ce67e6155da70a825e9d5d79e59599a755d367e44141ded2",
        b"cd9b37b7b5b5991b0ffaf799679ea174bdfcf2cbc12752942ae3d84f3251bfb037dbb76fa77b037a",
        b"d546cf9b2e7f35d01cbdbd386f695757576b6b2bbddaa557a34f3ffdf4b5d75e4b771de66f3714a5",
        b"e991f6131ef50be7813662f8f0e1c3860debecec7439bf397a7b71de527a11ba72e54aba75a71798",
        b"54de53a74eadfd5191a23437d27ec2a37e6145511445511445511445511445511445511445511445",
        b"511445518290c7df3a63c68cc45f68fa116a9c3c54c1635b441eeabfae50bed1e23ca155a8b7fc84",
        b"ca0ff21497c5ba75ebd6af5f2ffdae2a5cbf55238fe3ef95575ed9b367cf39e79c93f31a09354e1e",
        b"aae03a2c220f755e5740df68719ed02ad45b7e82e487f11497c5ecd9b3e9694bfa5d55b87eab46fe",
        b"9c5c78e18541ae9150e3f8519dda089b873aafab817ca3e5d65b45a89aa7f8edb7df1ed44b2c2c70",
        b"24549d57cd2758a8bf3533cef43562f53932fe4aeb384c3e2b9507c66526f5b186ca035a97289ecc",
        b"fd4a13ca9f8b3ca1287e2b8cffd79ae7485e3fd2eb178d2ff5f032be57519c68bfac04f4b1323cfc",
        b"f0c314fc800103bababa32d725bd7e5da89a4fb0507f6b669ce96bc4ea7364fc95681c94cf4ae521",
        b"b3b7bbfb5843e501ad4b144fe67ea509e5cf459e5014bf15c6ff8bf22cad1fe9f58bc6977a78517e",
        b"a471a2fdb212d0c7ca3077eedc79f3e67dee739fa37f33d725bd7e33a9b84f30b8bf3533cec43582",
        b"7c8e99fecaf4b566cd67d5f2c0782aa53ed6207960d6258a2773bfac84f2e746367706e3574d93e9",
        b"ffe5df93c9ac9f28dff55b3bbed4c36b48e7c7234ec6539c20948f9581369452f1c8238fac5fbf9e",
        b"1ec4fb1beafacda4823ec142fdad997126ae11e473ccf457a6af356b3eab9607c65329f5b106c903",
        b"b32e513c99fb6525943f37c2bdddea574dc3f87f0de93c8bea27925fbf687ca98717e5c7234ec653",
        b"9c20948f95814a975afabbefbe4b4d83ea3c9e2bd4f59b49d57c8245fb5b33e3b4f6f6b4cf31d35f",
        b"69bd8f4ae7b36a79603c95521f6b903c30eb12c593b95f5642f97323dcdb91cb2301f2ffc65f26f2",
        b"2cad9ff81b1daf5f667ca98717e5c7234ec6539c20948f95e1d24b2fa5d76eefefa55fbf7eb44066",
        b"5dded72f43d57c8275f0b7f27126ae11c6e7c8fb2bad3d2d9dcf0ae601792aa53ed6207960d6258d",
        b"87df2f2ba1fcb951a0de9ef6ffc62724f22cad9f4878fd32e34b3dbc283f1e71329ee2347e3e567a",
        b"5270311ad373d9f1c71f7ff7dd77ffa297db6ebb8dbe34ef4386ba7e5da8944fb0687f2b13e7debd",
        b"7bcdef094f9d3a951ed097e65b90cf11f92bd138289f55cb03f2db4a7dac41f2c0ac4b1a0fda2f86",
        b"20fe5ce409f5e8ed69ff6f04f22cad1fa98794195feae145f9f188d3ba5f080f1f2b2d879e116a3b",
        b"2482863de69863e227055a232ddfbcc313ca43ed42d57c8245fb5b519c1ffbd8c76adf2c8d7f7f03",
        b"f91c91bf128d83f259b53c204fa5d4c71a2a0f685dd278d07ef1e4f7e7224fa8476fb7fa7f519ea5",
        b"f523f590a2f1a51e5e941fbf38d3fb85f0f0b1522952ab5fb264099f19e2ab5ffd2af5eada23f452",
        b"910e32ebf2f308e7417d82610995cf4647f320a2513c62eae1ad3eea130c4bd87c362e9a073f1aa5",
        b"b7ab87b7faa84f302c61f3d9b8681efc6894deae1e5e455114455114455114455114455114455114",
        b"45511445511445514aa1fa5ebfb05ec8e2fc8c7e3e4df7f1c382c697e6a7e83c48a99a37b368aa96",
        b"7f297d6dbfea49f5bd7e61bd90c5f919033ad78af63f32e38bf253741ea454d09b592855cbbf94be",
        b"b65ff5a474af9f3b95f24216edd32cdaff186afcaa7945abe6cd2c9aaae55f4a5fdbaf7a52a8d70f",
        b"7924913f91f748e6f76f4afd8c88503e4dd1f88cf7138d8fd685e247f961c617e58161fdfaf5eded",
        b"ed54876d6d6d6bd6acc99cd77d5d520fac475da1f8ad754e5d977242c7478e1cf9e4934f4e983081",
        b"1eecdbb78f592fa2e83a44fe53a93f97f1b75ae3578250a8d70f7924913f91f748e6f76f4afd8c88",
        b"503e4dd1f88cf7138d8fd685e247f941e34bf380e8ecececdfbfff8a152b76ecd871fbedb753bb30",
        b"9f8317645d1e1e58695da1f8ad754e03b6f4ba44274f9e3c64c810bab93af5d4536fbef96666bd88",
        b"a2eb10f94fa5fe5c74bd8b3ca78a8842bd7e991e4943ad3f91f74886f290bafb191902fa341dc747",
        b"de4f667c665d8c5f32911f3e7ef73c20e866efc4134fa4728a8f98cf210fb52ea9073612d6158a3f",
        b"415ce7d4dbcd3e52bb3bf7dc73e901f5ba6baeb926549d44e1ea10f94ffdfcb9893c30f12bf929d4",
        b"ebc77824913f91f748e6f7901adcfd8c0c017d9a8ee323ef27333eb32ec62f99c80f1fbf7b1ed04a",
        b"f7eddbd7f27f454299f38ad625f5c046c2ba42f147a0cea9b79f71c619f4bf575f7df525975c12f5",
        b"16363d0e552751b83a44fe53a93f97f1a5ba7b4e1511857afd904792f127f2ce829cfecd18a99fd1",
        b"4a409fa6e3f8c8fbc98ccfac8bf14b26f2c3c7ef9e07b452d31bd39f021d6a5d520facc1bdae50fc",
        b"a8ce516f0f552751b83ab4fa4f23a1af96f7a5ba7b4e15778af6fa218f24e34ff4e8edeefecd9820",
        b"bd3da04fd37d7cabf793199f5917e3974ce4878fdf3d0f68a514d2b061c3aeb8e28af888f13b045c",
        b"97c8036b70af2b143faa73d4db03d649a83ab4fa4f23a1af96f7a58a3ca78a2375f0fa593d928c3f",
        b"115d6ba1fc9b223f233f54109fa6747ce4fd44e333ebb28e8ff2c3c42fca0362f5ead55412cb972f",
        b"a73e40b3b4b7b7f7f4f4045c97d4031b09ebca1a3faa73d4dbf93c230aad43abff94c99bf47a47f1",
        b"2b39a983d70f7924913f11d54c28ffa6d4cfc893dfa7291d1f793fd1f8fcbad2e3a3fcf0f1bbe781",
        b"61eddab5b4ad541263c68c59b56a55d875493db006f7ba42f15beb9ce9eda1ea24541d22ffa9d457",
        b"8bae7714bfa218d4bfa914411faf2bf59f2a65a1fe4da508b4ae0cea3f55ca42fd9b4a11685d19d4",
        b"7faa288aa2288aa2288aa2288aa2288aa2288aa2288aa2288aa2288a12f9fa10d33e56a9c7337d3e",
        b"f2ae56d3c71a0af5512a8a121c6f1f62dad927f59ca6cf47ded50afa5843a13e4a45518ac0db8758",
        b"9c8f1579572be5630d85fa2815a50f52351f22f2b1228f274d346bd6ace38e3b8ebee5bcf3ce8bff",
        b"421c9d6f70eced8c8b4d3aef6f7ef39bcb2fbffc84134e38fef8e3e9412c9db17a3f3d7c9a522faa",
        b"a228cd4dd57c88c8c78a3c9e0b162ca020299ec71f7f9c9e14284e731c9d6fc8dfdba5f3d2b0d49f",
        b"37f6327cf8703ac11cb77a3f3d7c9a522faaa228cd4da57c88993ed6b453e32b5ff90abde2f8f5af",
        b"7f1df57e54ddcf7ffef3daff4d9f6f70eced8c6753342f35d5da71e8d5107d495d3702de4f0f9fa6",
        b"9f1755519466a5523ec44c1f6bba57d3ffd23d33b5b2cf7ffef3c62a524bcedece783645f3767676",
        b"d238f193dd5b6fbd455fd20b9308783f3d7c9a7e5e5445519a954af910337daca8575360575c71c5",
        b"c08103bffce52fd71ecfd9db19cfa6685ed3dba9a59b2fcd5b3d716f4f3b263c7c9a7e5e5445519a",
        b"954af910337dace95e5dfba1a3c6e75ebb909cbd3dc29e4dd1bcbb77efa613e85589f9d278707efc",
        b"e31f47c2de1edc8b4a4f5ec6bca0284a9351351f22f2b15a3d9eefbefbee09279c307ffefc4d9b36",
        b"d1d4b367cf3ee9a4934cb342de4fe45d45c7ad9e4d8f79cf3befbcf867a923468c983973a6392eea",
        b"ed28ff681c3effb4ddf4cce562e45414a5e1a89a0f11f95891c773cb962de67d6f5ac259679d656e",
        b"8699f39177151d479e4de9bc6fbdf5d682050b8eef851ec4efcf487b7b287fa849353d252d59b284",
        b"d90e45511a11f5212a8aa2341fea43541445693efe5f7b772c0000000030c8df7a14fb4a241f2200",
        b"00000000000000000000000000000000000000000000000000000000000000000000000000000000",
        b"00000000000000000000000000000000000000000000000000000000000000000000000000000000",
        b"00000000000000000000000000000000000000000000000000000000000000c02dfbaca254000e00",
        b"0001030001000000f401000001010300010000005802000002010300030000005c79000003010300",
        b"01000000080000000601030001000000020000001101040001000000080000001201030001000000",
        b"01000000150103000100000003000000160103000100000058020000170104000100000095780000",
        b"1a010500010000004c7900001b01050001000000547900001c010300010000000100000028010300",
        b"0100000002000000000000002c010000010000002c01000001000000080008000800"
    ))
end

# =================================================================================================
"""
    sample_pix()::Pix

Generate a sample image with text.

__Details:__

The primary purpose of this method is to make it easier to demonstrate the functionality of the
Tesseract library by providing a Pix object for an image with text that can be processed by
Tesseract.

The text on this image is the first paragraph of the book War of World by H.G. Wells. This book is
in the public domain, so no copyright exists.

__Example:__

```jldoctest
julia> using Tesseract

julia> update_languages()
true

julia> instance = TessInst()
Allocated Tesseract instance.

julia> pix = sample_pix()
Image (500, 600) at 32ppi

julia> tess_image(instance, pix)

julia> tess_resolution(instance, 72)

julia> text = tess_text(instance);
```

See also: [`sample_tiff`](@ref)
"""
function sample_pix()::Pix
    local data = sample_tiff()
    return pix_read_tiff(data)
end
